<?php

class St_Adamas_Calendar_Widget extends WP_Widget {

	private static $instance = 0;

	function __construct() {
		$widget_ops = array(
			'classname'                   => 'widget_calendar',
			'description'                 => esc_html__( 'A calendar of your site&#8217;s Posts.', 'adamas-custom-widgets' ),
			'customize_selective_refresh' => true,
		);
		parent::__construct( 'calendar', esc_html__( 'Calendar', 'adamas-custom-widgets' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		/** This filter is documented in wp-includes/widgets/class-wp-widget-pages.php */
		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

		echo $args['before_widget'];
		if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}
		if ( 0 === self::$instance ) {
			echo '<div id="calendar_wrap" class="calendar_wrap">';
		} else {
			echo '<div class="calendar_wrap">';
		}

		if ( ! function_exists( 'get_new_calendar' ) ) {
			function get_new_calendar( $initial = true, $echo = true ) {
				global $wpdb, $m, $monthnum, $year, $wp_locale, $posts;

				$key   = md5( $m . $monthnum . $year );
				$cache = wp_cache_get( 'get_calendar', 'calendar' );

				if ( $cache && is_array( $cache ) && isset( $cache[ $key ] ) ) {
					/** This filter is documented in wp-includes/general-template.php */
					$output = apply_filters( 'get_calendar', $cache[ $key ] );

					if ( $echo ) {
						echo $output;

						return;
					}

					return $output;
				}

				if ( ! is_array( $cache ) ) {
					$cache = array();
				}

				// Quick check. If we have no posts at all, abort!
				if ( ! $posts ) {
					$gotsome = $wpdb->get_var( "SELECT 1 as test FROM $wpdb->posts WHERE post_type = 'post' AND post_status = 'publish' LIMIT 1" );
					if ( ! $gotsome ) {
						$cache[ $key ] = '';
						wp_cache_set( 'get_calendar', $cache, 'calendar' );

						return;
					}
				}

				if ( isset( $_GET['w'] ) ) {
					$w = (int) $_GET['w'];
				}
				// week_begins = 0 stands for Sunday
				$week_begins = (int) get_option( 'start_of_week' );
				$ts          = current_time( 'timestamp' );

				// Let's figure out when we are
				if ( ! empty( $monthnum ) && ! empty( $year ) ) {
					$thismonth = zeroise( intval( $monthnum ), 2 );
					$thisyear  = (int) $year;
				} elseif ( ! empty( $w ) ) {
					// We need to get the month from MySQL
					$thisyear = (int) substr( $m, 0, 4 );
					//it seems MySQL's weeks disagree with PHP's
					$d         = ( ( $w - 1 ) * 7 ) + 6;
					$thismonth = $wpdb->get_var( "SELECT DATE_FORMAT((DATE_ADD('{$thisyear}0101', INTERVAL $d DAY) ), '%m')" );
				} elseif ( ! empty( $m ) ) {
					$thisyear = (int) substr( $m, 0, 4 );
					if ( strlen( $m ) < 6 ) {
						$thismonth = '01';
					} else {
						$thismonth = zeroise( (int) substr( $m, 4, 2 ), 2 );
					}
				} else {
					$thisyear  = gmdate( 'Y', $ts );
					$thismonth = gmdate( 'm', $ts );
				}

				$unixmonth = mktime( 0, 0, 0, $thismonth, 1, $thisyear );
				$last_day  = date( 't', $unixmonth );

				// Get the next and previous month and year with at least one post
				$previous = $wpdb->get_row( "SELECT MONTH(post_date) AS month, YEAR(post_date) AS year
					FROM $wpdb->posts
					WHERE post_date < '$thisyear-$thismonth-01'
					AND post_type = 'post' AND post_status = 'publish'
						ORDER BY post_date DESC
						LIMIT 1" );
				$next     = $wpdb->get_row( "SELECT MONTH(post_date) AS month, YEAR(post_date) AS year
					FROM $wpdb->posts
					WHERE post_date > '$thisyear-$thismonth-{$last_day} 23:59:59'
					AND post_type = 'post' AND post_status = 'publish'
						ORDER BY post_date ASC
						LIMIT 1" );

				/* translators: Calendar caption: 1: month name, 2: 4-digit year */
				$calendar_caption = _x( '%1$s %2$s', 'calendar caption', 'adamas-custom-widgets' );
				$calendar_output  = '<table id="wp-calendar">';
				$calendar_output  .= '<caption>';

				if ( $previous ) {
					$calendar_output .= "\n\t\t" . '<span id="prev"><a href="' . get_month_link( $previous->year, $previous->month ) . '"><i class="fa fa-angle-left" aria-hidden="true"></i></a></span>';
				} else {
					$calendar_output .= "\n\t\t" . '<span id="prev" class="pad">&nbsp;</span>';
				}

				$calendar_output .= sprintf(
					$calendar_caption,
					$wp_locale->get_month( $thismonth ),
					date( 'Y', $unixmonth )
				);

				if ( $next ) {
					$calendar_output .= "\n\t\t" . '<span id="next"><a href="' . get_month_link( $next->year, $next->month ) . '"><i class="fa fa-angle-right" aria-hidden="true"></i></a></span>';
				} else {
					$calendar_output .= "\n\t\t" . '<span id="next" class="pad">&nbsp;</span>';
				}

				$calendar_output .= '</caption>
				<thead>
				<tr>';

				$myweek = array();

				for ( $wdcount = 0; $wdcount <= 6; $wdcount ++ ) {
					$myweek[] = $wp_locale->get_weekday( ( $wdcount + $week_begins ) % 7 );
				}

				foreach ( $myweek as $wd ) {
					$day_name        = $initial ? $wp_locale->get_weekday_initial( $wd ) : $wp_locale->get_weekday_abbrev( $wd );
					$wd              = esc_attr( $wd );
					$calendar_output .= "\n\t\t<th scope=\"col\" title=\"$wd\">$day_name</th>";
				}

				$calendar_output .= '
				</tr>
				</thead>';

				$calendar_output .= '
				<tbody>
				<tr>';

				$daywithpost = array();

				// Get days with posts
				$dayswithposts = $wpdb->get_results( "SELECT DISTINCT DAYOFMONTH(post_date)
					FROM $wpdb->posts WHERE post_date >= '{$thisyear}-{$thismonth}-01 00:00:00'
					AND post_type = 'post' AND post_status = 'publish'
					AND post_date <= '{$thisyear}-{$thismonth}-{$last_day} 23:59:59'", ARRAY_N );
				if ( $dayswithposts ) {
					foreach ( (array) $dayswithposts as $daywith ) {
						$daywithpost[] = $daywith[0];
					}
				}

				// See how much we should pad in the beginning
				$pad = calendar_week_mod( date( 'w', $unixmonth ) - $week_begins );
				if ( 0 != $pad ) {
					$calendar_output .= "\n\t\t" . '<td colspan="' . esc_attr( $pad ) . '" class="pad">&nbsp;</td>';
				}

				$newrow      = false;
				$daysinmonth = (int) date( 't', $unixmonth );

				for ( $day = 1; $day <= $daysinmonth; ++ $day ) {
					if ( isset( $newrow ) && $newrow ) {
						$calendar_output .= "\n\t</tr>\n\t<tr>\n\t\t";
					}
					$newrow = false;

					if ( $day == gmdate( 'j', $ts ) &&
					     $thismonth == gmdate( 'm', $ts ) &&
					     $thisyear == gmdate( 'Y', $ts ) ) {
						if ( in_array( $day, $daywithpost ) ) {
							// any posts today?
							$date_format     = date( esc_html_x( 'F j, Y', 'daily archives date format', 'adamas-custom-widgets' ), strtotime( "{$thisyear}-{$thismonth}-{$day}" ) );
							$label           = sprintf( esc_html__( 'Posts published on %s', 'adamas-custom-widgets' ), $date_format );
							$calendar_output .= '<td id="today" class="with-link">';
							$calendar_output .= sprintf(
								'<a href="%s" aria-label="%s">%s</a>',
								get_day_link( $thisyear, $thismonth, $day ),
								esc_attr( $label ),
								$day
							);
						} else {
							$calendar_output .= '<td id="today">';
							$calendar_output .= $day;
							$calendar_output .= '</td>';
						}
					} else {
						if ( in_array( $day, $daywithpost ) ) {
							// any posts today?
							$date_format     = date( _x( 'F j, Y', 'daily archives date format', 'adamas-custom-widgets' ), strtotime( "{$thisyear}-{$thismonth}-{$day}" ) );
							$label           = sprintf( esc_html__( 'Posts published on %s', 'adamas-custom-widgets' ), $date_format );
							$calendar_output .= '<td class="with-link">';
							$calendar_output .= sprintf(
								'<a href="%s" aria-label="%s">%s</a>',
								get_day_link( $thisyear, $thismonth, $day ),
								esc_attr( $label ),
								$day
							);
						} else {
							$calendar_output .= '<td>';
							$calendar_output .= $day;
							$calendar_output .= '</td>';
						}
					}

					if ( 6 == calendar_week_mod( date( 'w', mktime( 0, 0, 0, $thismonth, $day, $thisyear ) ) - $week_begins ) ) {
						$newrow = true;
					}
				}

				$pad = 7 - calendar_week_mod( date( 'w', mktime( 0, 0, 0, $thismonth, $day, $thisyear ) ) - $week_begins );
				if ( $pad != 0 && $pad != 7 ) {
					$calendar_output .= "\n\t\t" . '<td class="pad" colspan="' . esc_attr( $pad ) . '">&nbsp;</td>';
				}
				$calendar_output .= "\n\t</tr>\n\t</tbody>\n\t</table>";

				$cache[ $key ] = $calendar_output;
				wp_cache_set( 'get_calendar', $cache, 'calendar' );

				if ( $echo ) {
					/**
					 * Filter the HTML calendar output.
					 *
					 * @since 3.0.0
					 *
					 * @param string $calendar_output HTML output of the calendar.
					 */
					echo apply_filters( 'get_calendar', $calendar_output );

					return;
				}

				/** This filter is documented in wp-includes/general-template.php */
				return apply_filters( 'get_calendar', $calendar_output );
			}
		}

		get_new_calendar();

		echo '</div>';
		echo $args['after_widget'];

		self::$instance ++;
	}

	function update( $new_instance, $old_instance ) {
		$instance          = $old_instance;
		$instance['title'] = sanitize_text_field( $new_instance['title'] );

		return $instance;
	}

	function form( $instance ) {
		$instance = wp_parse_args( (array) $instance, array( 'title' => '' ) );
		$title    = sanitize_text_field( $instance['title'] );
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>"/></p>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Calendar_Widget' );
} );

?>