<?php

class St_Adamas_Widget_Layered_Nav_Filters extends WC_Widget {

	function __construct() {
		$this->widget_cssclass    = 'woocommerce widget_layered_nav_filters';
		$this->widget_description = esc_html__( 'Shows active layered nav filters so users can see and deactivate them.', 'adamas-custom-widgets' );
		$this->widget_id          = 'woocommerce_layered_nav_filters';
		$this->widget_name        = esc_html__( 'WooCommerce Layered Nav Filters', 'adamas-custom-widgets' );
		$this->settings           = array(
			'title' => array(
				'type'  => 'text',
				'std'   => esc_html__( 'Active Filters', 'adamas-custom-widgets' ),
				'label' => esc_html__( 'Title', 'adamas-custom-widgets' )
			)
		);

		parent::__construct();
	}

	function widget( $args, $instance ) {
		if ( ! is_post_type_archive( 'product' ) && ! is_tax( get_object_taxonomies( 'product' ) ) ) {
			return;
		}

		$_chosen_attributes = WC_Query::get_layered_nav_chosen_attributes();
		$min_price          = isset( $_GET['min_price'] ) ? wc_clean( $_GET['min_price'] ) : 0;
		$max_price          = isset( $_GET['max_price'] ) ? wc_clean( $_GET['max_price'] ) : 0;
		$min_rating         = isset( $_GET['min_rating'] ) ? absint( $_GET['min_rating'] ) : 0;

		if ( 0 < count( $_chosen_attributes ) || 0 < $min_price || 0 < $max_price || 0 < $min_rating ) {

			$this->widget_start( $args, $instance );

			echo '<ul>';

			// Attributes
			if ( ! empty( $_chosen_attributes ) ) {
				foreach ( $_chosen_attributes as $taxonomy => $data ) {
					foreach ( $data['terms'] as $term_slug ) {
						if ( ! $term = get_term_by( 'slug', $term_slug, $taxonomy ) ) {
							continue;
						}

						$filter_name    = 'filter_' . sanitize_title( str_replace( 'pa_', '', $taxonomy ) );
						$current_filter = isset( $_GET[ $filter_name ] ) ? explode( ',', wc_clean( $_GET[ $filter_name ] ) ) : array();
						$current_filter = array_map( 'sanitize_title', $current_filter );
						$new_filter     = array_diff( $current_filter, array( $term_slug ) );

						$link = remove_query_arg( array( 'add-to-cart', $filter_name ) );

						if ( sizeof( $new_filter ) > 0 ) {
							$link = add_query_arg( $filter_name, implode( ',', $new_filter ), $link );
						}

						echo '<li class="chosen"><a title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">' . esc_html( $term->name ) . '</a><a class="st-remove-filter" title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">×</a></li>';
					}
				}
			}

			if ( $min_price ) {
				$link = remove_query_arg( 'min_price' );
				echo '<li class="chosen"><a title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">' . esc_html__( 'Min', 'adamas-custom-widgets' ) . ' ' . wc_price( $min_price ) . '</a><a class="st-remove-filter" title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">×</a></li>';
			}

			if ( $max_price ) {
				$link = remove_query_arg( 'max_price' );
				echo '<li class="chosen"><a title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">' . esc_html__( 'Max', 'adamas-custom-widgets' ) . ' ' . wc_price( $max_price ) . '</a><a class="st-remove-filter" title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">×</a></li>';
			}

			if ( $min_rating ) {
				$link = remove_query_arg( 'min_rating' );
				echo '<li class="chosen"><a title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">' . sprintf( esc_html__( 'Rated %s and above', 'adamas-custom-widgets' ), $min_rating ) . '</a><a class="st-remove-filter" title="' . esc_attr__( 'Remove filter', 'adamas-custom-widgets' ) . '" href="' . esc_url( $link ) . '">×</a></li>';
			}

			echo '</ul>';

			$this->widget_end( $args );
		}
	}
}


add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Widget_Layered_Nav_Filters' );
} );