<?php
/*
 * Add-on Name: Partners Module
 */
if ( ! class_exists( 'St_Partners_Module' ) ) {
	class St_Partners_Module {
		function __construct() {
			add_shortcode( 'st_partners_module', array( $this, 'partners_module_shortcode' ) );
			add_action( 'init', array( $this, 'partners_module_init' ) );
		}

		function partners_module_shortcode( $atts ) {
			$partners_data = '';
			$company_logo  = '';
			$el_class      = $partners_width = $partners_underline = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'partners_data'        => '',
				'partners_width'       => '',
				'partners_underline'   => '',
				'partners_logos_color' => '',
				'module_animation'     => '',
				'el_class'             => '',
			), $atts ) );

			$company_logo_count = 0;
			$output             = '';

			$partners_data = json_decode( urldecode( $partners_data ), true );

			$id = uniqid( 'st-partners-' );

			if ( empty( $partners_width ) ) {
				$partners_width = 'half';
			}

			if ( $partners_width == 'full' ) {
				$quantity = '5';
			} else {
				$quantity = '3';
			}

			if ( $partners_logos_color ) {
				$el_class .= ' colored';
			}

			if ( $partners_underline ) {
				$el_class .= ' underline';
			}

			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . esc_attr( $module_animation ) . '"';
			}

			$output .= '<div class="st-partners-wrapper"><div id="' . esc_attr( $id ) . '" class="st-partners-logo-slider ' . esc_attr( $el_class ) . ' ' . esc_attr( $partners_width ) . ' ' . esc_attr( $animated ) . '" ' . $animation . '>';
			if ( isset( $partners_data ) ) {
				foreach ( $partners_data as $partners_datas ) {
					$company_logo_count ++;
					$partners_img      = wp_get_attachment_image_src( $partners_datas['company_logo'], 'full' );
					$partners_img_alt  = strip_tags( get_post_meta( $partners_datas['company_logo'], '_wp_attachment_image_alt', true ) );
					$partners_img_link = $partners_img[0];
					$partners_link     = isset( $partners_datas['company_link'] ) && ! empty( $partners_datas['company_link'] ) ? $partners_datas['company_link'] : '';
					$output            .= '<div class="st-partners-logo">';
					if ( $partners_link !== '' ) {
						$output .= '<a href="' . esc_url( $partners_link ) . '" target="_blank" rel="noopener noreferrer">';
					}
					$output .= '<img src="' . esc_url( $partners_img_link ) . '" alt="' . esc_attr( $partners_img_alt ) . '">';
					if ( $partners_link !== '' ) {
						$output .= '</a>';
					}
					$output .= '</div>';
				}
			}
			$output .= '</div>'; // st-partners-logo-slider
			$output .= '</div>'; // st-partners-wrapper

			wp_enqueue_script( 'slick' );

			$rtl = '';
			if ( is_rtl() ) {
				$rtl = 'rtl:true';
			}

			$output .= '<script type="text/javascript">';
			$output .= '(function($){';
			$output .= '"use strict";';
			if ( $company_logo_count == 1 || $company_logo_count == 2 ) {
				$output .= '$("head").append("<style>.st-partners-wrapper .st-partners-logo-slider .slick-list{width:160px;overflow:hidden}</style>");';
			} else if ( $company_logo_count == 3 || $company_logo_count == 4 ) {
				$output .= '$("head").append("<style>.st-partners-wrapper .st-partners-logo-slider .slick-list{width:500px;overflow:hidden}</style>");';
			}
			$output .= '$(document).ready(function(){';
			$output .= '$("#' . esc_js( $id ) . '").slick({rows:0,slidesToShow:' . esc_js( $quantity ) . ',slidesToScroll:1,arrows:false,swipeToSlide:false,centerMode:true,focusOnSelect:true,responsive:[{breakpoint:1200,settings:{slidesToShow:3}},{breakpoint:767,settings:{slidesToShow:1}}],' . esc_js( $rtl ) . '});';
			$output .= '});';
			$output .= '})(jQuery);';
			$output .= '</script>';

			return $output;
		}

		function partners_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Partners', 'adamas-vc-shortcodes' ),
					'base'        => 'st_partners_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/partners.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Partners logos in slider', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'       => 'text',
							'param_name' => 'title_text',
							'heading'    => __( '<h4>Partners Content</h4>', 'adamas-vc-shortcodes' ),
							'value'      => '',
						),
						array(
							'type'        => 'param_group',
							'param_name'  => 'partners_data',
							'description' => __( 'Add partners here.', 'adamas-vc-shortcodes' ),
							'value'       => urlencode( json_encode( array(
								array(
									'company_logo' => '',
									'company_link' => '',
								)
							) ) ),
							'params'      => array(
								array(
									'type'       => 'attach_image',
									'heading'    => __( 'Company logo', 'adamas-vc-shortcodes' ),
									'param_name' => 'company_logo',
								),
								array(
									'type'       => 'textfield',
									'heading'    => __( 'Company link', 'adamas-vc-shortcodes' ),
									'param_name' => 'company_link',
								),
							),
						),
						array(
							'type'       => 'dropdown',
							'param_name' => 'partners_width',
							'heading'    => __( 'Block width', 'adamas-vc-shortcodes' ),
							'value'      => array(
								__( 'Half width', 'adamas-vc-shortcodes' ) => 'half',
								__( 'Full width', 'adamas-vc-shortcodes' ) => 'full',
							),
						),
						array(
							'type'        => 'checkbox',
							'param_name'  => 'partners_logos_color',
							'heading'     => __( 'Colored logos?', 'adamas-vc-shortcodes' ),
							'description' => __( 'Check this if uploaded logos are colored.', 'adamas-vc-shortcodes' ),
							'value'       => array( __( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
						),
						array(
							'type'        => 'checkbox',
							'param_name'  => 'partners_underline',
							'heading'     => __( 'Underline marker?', 'adamas-vc-shortcodes' ),
							'description' => __( 'Check this to enable center image underline marker.', 'adamas-vc-shortcodes' ),
							'value'       => array( __( 'Yes', 'adamas-vc-shortcodes' ) => 'yes' ),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
					)
				) );
			}
		}
	}

	$st_partners_module = new St_Partners_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_partners_module extends WPBakeryShortCode {
		}
	}
}