<?php
/*
* Add-on Name: Projects Portfolio Module
*/
if ( ! class_exists( 'St_Projects_Portfolio_Module' ) ) {
	class St_Projects_Portfolio_Module {
		function __construct() {
			add_shortcode( 'st_projects_portfolio_module', array( $this, 'projects_portfolio_module_shortcode' ) );
			add_action( 'init', array( $this, 'projects_portfolio_module_init' ) );
		}

		function projects_portfolio_module_shortcode( $atts ) {
			$output = $portfolio_select = $portfolio_layout = $portfolio_layout_item = $portfolio_projects = $portfolio_items_amount = $filter_panel = $filter_panel_block = $filter_panel_position = $columns_padding = $portfolio_pagination_type = $portfolio_image_height = $portfolio_image_width = $el_class = $module_animation = $animation = $animated = $inner_animated = '';
			extract( shortcode_atts( array(
				'portfolio_select'          => '',
				'portfolio_layout'          => '',
				'portfolio_layout_item'     => '',
				'portfolio_categories'      => '',
				'portfolio_projects'        => '',
				'column_padding'            => '',
				'column_amount'             => '',
				'portfolio_items_amount'    => '',
				'portfolio_image_width'     => '',
				'portfolio_image_height'    => '',
				'filter_panel'              => '',
				'filter_panel_position'     => '',
				'portfolio_pagination_type' => '',
				'module_animation'          => '',
				'el_class'                  => ''
			), $atts ) );

			// Animation
			if ( $module_animation ) {
				$animated       .= ' st-animation';
				$animation      .= 'data-animation="' . esc_attr( $module_animation ) . '"';
				$inner_animated .= 'data-animated=".st-portfolio-item"';
			}

			if ( empty( $portfolio_layout ) ) {
				$portfolio_layout = 'fitRows';
			}

			if ( empty( $portfolio_layout_item ) ) {
				$portfolio_layout_item = 'style-1';
			}

			if ( empty( $column_amount ) ) {
				$column_amount = 'one-column';
			}

			if ( $column_amount == 'one-column' ) {
				$columns = 1;
			} elseif ( $column_amount == 'two-column' ) {
				$columns = 2;
			} elseif ( $column_amount == 'three-column' ) {
				$columns = 3;
			} else {
				$columns = 4;
			}

			if ( empty( $portfolio_items_amount ) ) {
				$portfolio_items_amount = - 1;
			}

			if ( empty( $filter_panel ) ) {
				$filter_panel = false;
			}

			if ( empty( $filter_panel_position ) ) {
				$filter_panel_position = 'text-center';
			}

			if ( ! empty( $column_padding ) ) {
				$el_class .= ' ' . esc_attr( $column_padding );
			}

			$el_class .= ' ' . esc_attr( $portfolio_layout_item );

			if ( ! empty( $portfolio_image_width ) ) {
				$image_width = $portfolio_image_width;
			} else {
				if ( $column_amount == 'one-column' ) {
					$image_width = 1920;
				} elseif ( $column_amount == 'two-column' ) {
					$image_width = 960;
				} elseif ( $column_amount == 'three-column' ) {
					$image_width = 640;
				} else {
					$image_width = 480;
				}
			}

			if ( ! empty( $portfolio_image_height ) ) {
				$image_height = $portfolio_image_height;
			} else {
				if ( strcmp( $portfolio_layout, 'fitRows' ) === 0 || strcmp( $portfolio_layout, 'packery' ) === 0 ) {
					if ( $column_amount == 'one-column' ) {
						$image_height = 300;
					} elseif ( $column_amount == 'two-column' ) {
						$image_height = 600;
					} elseif ( $column_amount == 'three-column' ) {
						$image_height = 400;
					} else {
						$image_height = 400;
					}
				} else {
					$image_height = 800;
				}
			}

			if ( empty( $portfolio_select ) || ! isset( $portfolio_select ) ) {
				$portfolio_select = 'category';
			}

			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			} else {
				$paged = 1;
			}

			$projects_array = preg_split( '/[\s,]+/', $portfolio_projects );

			if ( ! empty( $portfolio_select ) && $portfolio_select == 'category' ) {
				$args = array(
					'tax_query'      => array(
						array(
							'taxonomy' => 'project_category',
							'field'    => 'slug',
							'terms'    => explode( ',', $portfolio_categories ),
						)
					),
					'post_type'      => 'projects',
					'posts_per_page' => $portfolio_items_amount,
					'paged'          => $paged,
				);
			} elseif ( ! empty( $portfolio_select ) && $portfolio_select == 'name' ) {
				$args = array(
					'post_type' => 'projects',
					'post__in'  => $projects_array,
					'paged'     => $paged,
				);
			} else {
				$args = array(
					'post_type' => 'projects',
					'post__in'  => $projects_array,
					'paged'     => $paged,
				);
			}

			$portfolio_cat_array = get_terms( 'project_category', array( 'slug' => explode( ',', $portfolio_categories ) ) );

			if ( ! empty( $portfolio_cat_array ) && is_array( $portfolio_cat_array ) && ! is_wp_error( $portfolio_cat_array ) ) {
				$filter_panel_block .= '<div class="st-portfolio-filter-panel ' . esc_attr( $filter_panel_position ) . ' ' . esc_attr( $animated ) . '" ' . $animation . '>';
				$filter_panel_block .= '<ul class="st-portfolio-filters">';
				$filter_panel_block .= '<li class="active"><a data-filter=".st-portfolio-item" href="#">' . __( 'All', 'adamas-vc-shortcodes' ) . '</a></li>';
				foreach ( $portfolio_cat_array as $portfolio_cat ) {
					$filter_panel_block .= '<li><a data-filter=".st-portfolio-item[data-category~=\'' . preg_replace( '/\s+/', '-', esc_attr( $portfolio_cat->slug ) ) . '\']" href="#">' . esc_attr( $portfolio_cat->name ) . '</a></li>';
				}
				$filter_panel_block .= '</ul>';
				$filter_panel_block .= '</div>';
			}

			$id = uniqid( 'st-portfolio-' );

			$output = '<div class="st-portfolio-module-container">';
			$output .= '<div class="st-portfolio-module ' . esc_attr( $el_class ) . '" id="' . esc_attr( $id ) . '">';

			if ( $filter_panel ) {
				$output .= $filter_panel_block;
			}

			$output .= '<div class="st-portfolio-items ' . esc_attr( $portfolio_layout ) . ' ' . esc_attr( $column_amount ) . ' ' . esc_attr( $animated ) . '" ' . $inner_animated . ' ' . $animation . '>';

			$loop = 1;

			$portfolio_query = new WP_Query( $args );
			while ( $portfolio_query->have_posts() ) : $portfolio_query->the_post();

				$column_class = '';
				if ( $loop == 1 ) {
					$column_class = 'double-width';
				}
				if ( $loop == 5 ) {
					$column_class = 'double-height';
				}

				$image = '';

				if ( has_post_thumbnail() ) {
					$image_id  = get_post_thumbnail_id();
					$image_url = wp_get_attachment_url( $image_id, 'full' );
					if ( strcmp( $portfolio_layout, 'fitRows' ) === 0 ) {
						$image = st_adamas_aq_resize( $image_url, $image_width, $image_height, true, true, true );
					} elseif ( strcmp( $portfolio_layout, 'packery' ) === 0 ) {
						if ( $loop == 1 ) {
							$new_image_width = $image_width * 2;
						} else {
							$new_image_width = $image_width;
						}
						if ( $loop == 5 ) {
							$new_image_height = $image_height * 2;
						} else {
							$new_image_height = $image_height;
						}
						$image = st_adamas_aq_resize( $image_url, $new_image_width, $new_image_height, true, true, true );
					} else {
						$image = st_adamas_aq_resize( $image_url, $image_width, $image_height, false, true, true );
					}
					if ( ! $image ) {
						$image = $image_url;
					}
					// TODO : st_adamas_aq_resize for 1-4 columns layout
				}

				$portfolio_item_id       = get_the_ID();
				$portfolio_item_terms    = get_the_terms( $portfolio_item_id, 'project_category' );
				$portfolio_data_category = '';
				$portfolio_name_category = '';

				if ( ! empty( $portfolio_item_terms ) && is_array( $portfolio_item_terms ) && ! is_wp_error( $portfolio_item_terms ) ) {
					foreach ( $portfolio_item_terms as $portfolio_item_term ) {
						$portfolio_name_category .= $portfolio_item_term->name;
						$portfolio_data_category .= $portfolio_item_term->slug . ' ';
					}
				}

				if ( get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
					$landing_disabled = 'soon';
				} else {
					$landing_disabled = '';
				}

				$link        = esc_url( get_permalink() );
				$landing_url = get_post_meta( get_the_ID(), 'st_landing_url', true );
				if ( ! empty( $landing_url ) ) {
					$link = esc_url( $landing_url );
				}

				$output .= '<article class="st-portfolio-item ' . esc_attr( $column_class ) . ' ' . esc_attr( $landing_disabled ) . '" data-category="' . esc_attr( $portfolio_data_category ) . '">';
				if ( ! get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
					$output .= '<a href="' . $link . '" title="' . esc_attr( get_the_title() ) . '">';
				}
				$output .= '<div class="st-portfolio-item-image">';
				$output .= '<div class="st-portfolio-item-overlay"><div class="overlay-inner-icon"></div><div class="overlay-inner-left"></div><div class="overlay-inner-right"></div></div>';
				if ( $image != '' ) {
					$output .= '<img src="' . esc_url( $image ) . '" alt="' . esc_attr( get_the_title() ) . '"/>';
				}
				$output .= '</div>'; // st-portfolio-item-image
				if ( ! get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
					$output .= '</a>';
				}
				if ( $portfolio_layout_item === 'style-2' || $portfolio_layout_item === 'style-3' ) {
					$output .= '<div class="st-portfolio-item-inner">';
					if ( ! get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
						$output .= '<a class="st-portfolio-item-inner-link" href="' . esc_url( $link ) . '"></a>';
					}
					$output .= '<div class="st-portfolio-item-category"><a href="' . esc_url( $link ) . '">' . esc_attr( $portfolio_item_term->name ) . '</a></div>';
				}
				$output .= '<div class="st-portfolio-item-title">';
				if ( ! get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
					$output .= '<a href="' . esc_url( $link ) . '">';
				}
				$output .= '<h4>' . esc_attr( get_the_title() ) . '</h4>';
				if ( ! get_post_meta( get_the_ID(), 'st_landing_disable_url', 1 ) ) {
					$output .= '</a>';
				}
				$output .= '</div>';
				$output .= '<div class="st-portfolio-item-desc">' . wp_kses_post( get_the_excerpt() ) . '</div>'; // TODO : If excerpt too long...
				if ( $portfolio_layout_item === 'style-2' || $portfolio_layout_item === 'style-3' ) {
					$output .= '</div>'; // st-portfolio-item-inner
				}
				$output .= '</article>'; // st-portfolio-item

				$loop ++;

			endwhile;

			$output .= '</div>'; // st-portfolio-items
			if ( $portfolio_pagination_type == 'st-portfolio-pagination' ) {
				$big    = 999999999; // need an unlikely integer
				$output .= '<div class="st-portfolio-pagination">';
				$output .= paginate_links( array(
					'base'      => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
					'format'    => '?paged=%#%',
					'prev_text' => __( 'Previous', 'adamas-vc-shortcodes' ),
					'next_text' => __( 'Next', 'adamas-vc-shortcodes' ),
					'total'     => $portfolio_query->max_num_pages
				) );
				$output .= '</div>';
			}

			$output .= '</div>'; // st-portfolio-module

			wp_enqueue_script( 'isotope', get_template_directory_uri() . '/assets/js/isotope.pkgd.min.js', false, null, true );
			if ( strcmp( $portfolio_layout, 'packery' ) === 0 ) {
				wp_enqueue_script( 'packery-mode', get_template_directory_uri() . '/assets/js/packery-mode.pkgd.min.js', false, null, true );
			}
			wp_enqueue_script( 'portfolio_isotope', get_template_directory_uri() . '/assets/js/portfolio.isotope.js', array( 'jquery' ), null, true );


			$output .= '<script type="text/javascript">';
			$output .= '(function($){';
			$output .= '"use strict";';
			$output .= '$(document).ready(function(){';
			$output .= '$("#' . esc_js( $id ) . '").StPortfolioModule("' . esc_js( $portfolio_layout ) . '");';
			$output .= '});';
			$output .= '})(jQuery);';
			$output .= '</script>';

			if ( $portfolio_pagination_type == 'st-portfolio-load-more' ) {
				wp_enqueue_script( 'st_adamas_portfolio_ajax_pagination', get_template_directory_uri() . '/assets/js/portfolio-ajax-pagination.js', array( 'jquery' ), null, true );

				$max = $portfolio_query->max_num_pages;
				wp_localize_script(
					'st_adamas_portfolio_ajax_pagination',
					'st_ajax_data',
					array(
						'startPage' => $paged,
						'maxPages'  => $max,
						'nextLink'  => next_posts( $max, false ),
						'container' => '.st-portfolio-items',
						'loadMore'  => __( 'Load more', 'adamas-vc-shortcodes' ),
						'noMore'    => __( 'No more items', 'adamas-vc-shortcodes' ),
					)
				);

				$output .= '<div class="st-portfolio-load-more"><a class="load-more-button" href="#" id="st-load-more">' . esc_html__( 'Load more', 'adamas-vc-shortcodes' ) . '</a><div class="st-load-more-animation lazy"><span></span><span></span><span></span></div></div>';
			}

			if ( $portfolio_pagination_type == 'st-portfolio-lazy' ) {
				wp_enqueue_script( 'st_adamas_portfolio_lazy_load', get_template_directory_uri() . '/assets/js/portfolio-lazy-load.js', array( 'jquery' ), false, true );

				$max = $portfolio_query->max_num_pages;
				wp_localize_script(
					'st_adamas_portfolio_lazy_load',
					'st_ajax_data',
					array(
						'startPage' => $paged,
						'maxPages'  => $max,
						'nextLink'  => next_posts( $max, false ),
						'container' => '.st-portfolio-items',
					)
				);

				$output .= '<div class="st-portfolio-load-more"><div class="st-load-more-animation lazy"><span></span><span></span><span></span></div></div>';
			}

			wp_reset_postdata();

			$output .= '</div>'; // st-portfolio-container

			return $output;
		}

		function projects_portfolio_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Projects Portfolio', 'adamas-vc-shortcodes' ),
					'base'        => 'st_projects_portfolio_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/projects_portfolio.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Projects in grid', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'       => 'dropdown',
							'heading'    => __( 'Portfolio to display', 'adamas-vc-shortcodes' ),
							'param_name' => 'portfolio_select',
							'value'      => array(
								__( 'By category', 'adamas-vc-shortcodes' ) => 'category',
								__( 'By title', 'adamas-vc-shortcodes' )    => 'name',
							),
						),
						array(
							'type'       => 'checkbox',
							'heading'    => __( 'Projects', 'adamas-vc-shortcodes' ),
							'param_name' => 'portfolio_projects',
							'value'      => st_adamas_projects_select(),
							'dependency' => Array( 'element' => 'portfolio_select', 'value' => array( 'name' ) ),
						),
						array(
							'type'       => 'checkbox',
							'class'      => '',
							'heading'    => __( 'Project categories', 'adamas-vc-shortcodes' ),
							'param_name' => 'portfolio_categories',
							'value'      => st_adamas_taxonomy_select( 'project_category' ),
							'dependency' => Array( 'element' => 'portfolio_select', 'value' => array( 'category' ) ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Portfolio item layout', 'adamas-vc-shortcodes' ),
							'param_name'  => 'portfolio_layout_item',
							'value'       => array(
								__( 'Title and description under image with icon on hover', 'adamas-vc-shortcodes' ) => 'style-1',
								__( 'Title, category and description on image hover', 'adamas-vc-shortcodes' )       => 'style-2',
								__( 'Title, category and description on image', 'adamas-vc-shortcodes' )             => 'style-3',
							),
							'description' => __( 'Select single portfolio item and hover styles.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Column amount', 'adamas-vc-shortcodes' ),
							'param_name'  => 'column_amount',
							'value'       => array(
								__( 'One column', 'adamas-vc-shortcodes' )    => 'one-column',
								__( 'Two columns', 'adamas-vc-shortcodes' )   => 'two-column',
								__( 'Three columns', 'adamas-vc-shortcodes' ) => 'three-column',
								__( 'Four columns', 'adamas-vc-shortcodes' )  => 'four-column',
							),
							'description' => __( 'Select column amount.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => '',
							'param_name'  => 'portfolio_layout',
							'value'       => array(
								__( 'Grid', 'adamas-vc-shortcodes' )    => 'fitRows',
								__( 'Masonry', 'adamas-vc-shortcodes' ) => 'masonry',
								__( 'Packery', 'adamas-vc-shortcodes' ) => 'packery',
							),
							'description' => __( 'Select portfolio layout. Masonry works only for 2-4 columns.', 'adamas-vc-shortcodes' ),
							'dependency'  => Array( 'element' => 'column_amount', 'value' => array( 'two-column', 'three-column', 'four-column' ) ),
						),
						array(
							'type'        => 'dropdown',
							'heading'     => __( 'Columns padding', 'adamas-vc-shortcodes' ),
							'param_name'  => 'column_padding',
							'value'       => array(
								__( 'No padding', 'adamas-vc-shortcodes' )     => '',
								__( 'Narrow padding', 'adamas-vc-shortcodes' ) => 'st-narrow-padding',
								__( 'Normal padding', 'adamas-vc-shortcodes' ) => 'st-normal-padding',
							),
							'description' => __( 'Select padding between columns.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Image width', 'adamas-vc-shortcodes' ),
							'param_name'  => 'portfolio_image_width',
							'description' => __( 'Set image width for porftfolio item in pixels. If empty, width will be set according to columns amount.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Image height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'portfolio_image_height',
							'description' => __( 'Set image height for porftfolio item in pixels. If empty, height will be set according to columns amount.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'       => 'checkbox',
							'class'      => '',
							'heading'    => __( 'Show filter panel.', 'adamas-vc-shortcodes' ),
							'param_name' => 'filter_panel',
							'value'      => array( __( 'Yes.', 'adamas-vc-shortcodes' ) => 'yes' ),
						),
						array(
							'type'       => 'dropdown',
							'class'      => '',
							'heading'    => __( 'Filter panel alignment', 'adamas-vc-shortcodes' ),
							'param_name' => 'filter_panel_position',
							'value'      => array(
								__( 'Left', 'adamas-vc-shortcodes' )   => 'text-left',
								__( 'Center', 'adamas-vc-shortcodes' ) => 'text-center',
								__( 'Right', 'adamas-vc-shortcodes' )  => 'text-right',
							),
							'dependency' => Array( 'element' => 'filter_panel', 'value' => 'yes' ),
						),
						array(
							'type'        => 'number',
							'class'       => '',
							'heading'     => __( 'Items amount', 'adamas-vc-shortcodes' ),
							'param_name'  => 'portfolio_items_amount',
							'value'       => '',
							'description' => __( 'Enter number of portfolio items to show.', 'adamas-vc-shortcodes' ),
							'dependency'  => Array( 'element' => 'portfolio_select', 'value' => array( 'category' ) ),
						),
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Pagination', 'adamas-vc-shortcodes' ),
							'param_name'  => 'portfolio_pagination_type',
							'value'       => array(
								__( 'None', 'adamas-vc-shortcodes' )             => '',
								__( 'Standard', 'adamas-vc-shortcodes' )       => 'st-portfolio-pagination',
								__( 'Load more button', 'adamas-vc-shortcodes' ) => 'st-portfolio-load-more',
								__( 'Lazy loading', 'adamas-vc-shortcodes' )     => 'st-portfolio-lazy',
							),
							'description' => __( 'Select pagination type for this portfolio.', 'adamas-vc-shortcodes' ),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_projects_portfolio_module = new St_Projects_Portfolio_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_projects_portfolio_module extends WPBakeryShortCode {
		}
	}
}