<?php
/*
* Add-on Name: Single Service Module
*/
if ( ! class_exists( 'St_Single_Service_Module' ) ) {
	class St_Single_Service_Module {
		function __construct() {
			add_shortcode( 'st_single_service_module', array( $this, 'single_service_module_shortcode' ) );
			add_action( 'init', array( $this, 'single_service_module_init' ) );
		}

		function single_service_module_shortcode( $atts, $content ) {
			$output = $service_title = $service_image = $service_link_text = $service_link = $module_animation = $animation = $animated = '';

			extract( shortcode_atts( array(
				'service_title'     => '',
				'service_image'     => '',
				'service_link_text' => '',
				'service_link'      => '',
				'module_animation'  => '',
				'el_class'          => '',
			), $atts ) );


			// Animation
			if ( $module_animation ) {
				$animated  .= ' st-animation';
				$animation .= 'data-animation="' . $module_animation . '"';
			}

			$img      = wp_get_attachment_image_src( $atts['service_image'], 'full' );
			$img_link = $img[0];

			$service_link       = $atts['service_link'];
			$service_link_build = vc_build_link( $service_link );

			if ( '' !== $service_link_build ) {
				$link_url    = $service_link_build['url'];
				$link_target = $service_link_build['target'];
				if ( ! empty( $service_link_build['rel'] ) ) {
					$rel = ' rel="' . esc_attr( $service_link_build['rel'] ) . '"';
				} else {
					$rel = '';
				}
			} else {
				$link_url = '';
			}

			if ( $img ) {
				$bg_img = ' style="background-image:url(' . esc_url( $img_link ) . ');"';
			}

			$content = wpb_js_remove_wpautop( $content, true );

			$output .= '<div class="st-single-service ' . esc_attr( $el_class ) . '" ' . $bg_img . '>';
			$output .= '<div class="st-single-service-inner">';
			$output .= '<div class="st-single-service-bg"></div>';
			$output .= '<div class="st-single-service-info ' . esc_attr( $animated ) . '" ' . $animation . '>';
			$output .= '<div class="st-single-service-title"><h3>' . esc_attr( $service_title ) . '</h3></div>';
			$output .= '<div class="st-single-service-desc">' . do_shortcode( $content ) . '</div>';
			$output .= '</div>'; // st-single-service-info
			if ( '' !== $link_url ) {
				$output .= '<div class="st-single-service-link"><a href="' . esc_url( $link_url ) . '" title="' . esc_attr( $service_title ) . '"';
				if ( $link_target != '' ) {
					$output .= ' target="' . esc_attr( trim( $link_target ) ) . '"' . $rel . '>';
				} else {
					$output .= $rel . '>';
				}
				$output .= esc_attr( $service_link_text );
				$output .= '</a></div>'; // st-single-service-link
			}
			$output .= '<div class="st-single-service-overlay-left"></div><div class="st-single-service-overlay-right"></div>';
			$output .= '</div>'; // st-single-service-inner
			$output .= '</div>'; // st-single-service

			return $output;
		}

		function single_service_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Single Service Item', 'adamas-vc-shortcodes' ),
					'base'        => 'st_single_service_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/simple_service_item.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Displays single service', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Service title', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_title',
							'description' => '',
							'admin_label' => true,
						),
						array(
							'type'        => 'attach_image',
							'heading'     => __( 'Service image', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_image',
							'description' => '',
						),
						array(
							'type'        => 'textarea_html',
							'heading'     => __( 'Service description', 'adamas-vc-shortcodes' ),
							'param_name'  => 'content',
							'description' => '',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Service link text', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_link_text',
							'description' => '',
						),
						array(
							'type'        => 'vc_link',
							'heading'     => __( 'Single service link', 'adamas-vc-shortcodes' ),
							'param_name'  => 'service_link',
							'description' => '',
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),
					)
				) );
			}
		}
	}

	$st_single_service_module = new St_Single_Service_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_single_service_module extends WPBakeryShortCode {
		}
	}
}