<?php
/*
* Add-on Name: Pricing Tables for WPBakery Page Builder
* Add-on URI: http://dev.brainstormforce.com
*/
if ( ! class_exists( "Ultimate_Pricing_Table" ) ) {
	class Ultimate_Pricing_Table {
		function __construct() {
			if ( Ultimate_VC_Addons::$uavc_editor_enable ) {
				add_action( "init", array( $this, "ultimate_pricing_init" ) );
			}
			add_shortcode( "ultimate_pricing", array( $this, "ultimate_pricing_shortcode" ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'price_table_assets' ), 1 );
		}

		function price_table_assets() {
			Ultimate_VC_Addons::ultimate_register_style( 'ultimate-pricing', 'pricing' );
		}

		function ultimate_pricing_init() {
			if ( function_exists( "vc_map" ) ) {
				vc_map(
					array(
						"name"        => __( "Price Box", "adamas-vc-shortcodes" ),
						"base"        => "ultimate_pricing",
						"class"       => "vc_ultimate_pricing",
						"icon"        => "vc_ultimate_pricing",
						"category"    => "Ultimate VC Addons",
						"description" => __( "Create nice looking pricing tables.", "adamas-vc-shortcodes" ),
						"params"      => array(
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Select Design Style", "adamas-vc-shortcodes" ),
								"param_name"  => "design_style",
								"value"       => array(
									__( "Design 01", "adamas-vc-shortcodes" )    => "design01",
									__( "Design 02", "adamas-vc-shortcodes" )    => "design02",
									__( "Design 03", "adamas-vc-shortcodes" )    => "design03",
									__( "Design 04", "adamas-vc-shortcodes" )    => "design04",
									__( "Design 05", "adamas-vc-shortcodes" )    => "design05",
									__( "Design 06", "adamas-vc-shortcodes" )    => "design06",
									__( "Theme Design", "adamas-vc-shortcodes" ) => "design07",
								),
								"description" => __( "Select Pricing table design you would like to use", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "attach_image",
								"class"       => "",
								"heading"     => __( "Background image for title section", "adamas-vc-shortcodes" ),
								"param_name"  => "bg_img",
								'description' => '',
								"dependency"  => Array( "element" => "design_style", "value" => array( "design07" ) ),
							),
							array(
								'type'        => 'colorpicker',
								"class"       => "",
								'heading'     => __( 'Background overlay color', 'adamas-vc-shortcodes' ),
								'param_name'  => 'bg_overlay',
								'description' => '',
								"dependency"  => Array( "element" => "design_style", "value" => array( "design07" ) ),
							),
							array(
								'type'        => 'colorpicker',
								'class'       => '',
								'heading'     => __( "Color for price table border and button", "adamas-vc-shortcodes" ),
								'param_name'  => 'table_color',
								'description' => '',
								"dependency"  => Array( "element" => "design_style", "value" => array( "design07" ) ),
							),
							array(
								"type"        => "dropdown",
								"class"       => "",
								"heading"     => __( "Select Color Scheme", "adamas-vc-shortcodes" ),
								"param_name"  => "color_scheme",
								"value"       => array(
									__( "Black", "adamas-vc-shortcodes" )           => "black",
									__( "Red", "adamas-vc-shortcodes" )             => "red",
									__( "Blue", "adamas-vc-shortcodes" )            => "blue",
									__( "Yellow", "adamas-vc-shortcodes" )          => "yellow",
									__( "Green", "adamas-vc-shortcodes" )           => "green",
									__( "Gray", "adamas-vc-shortcodes" )            => "gray",
									__( "Design Your Own", "adamas-vc-shortcodes" ) => "custom",
								),
								"description" => __( "Which color scheme would like to use?", "adamas-vc-shortcodes" )
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Main background Color", "adamas-vc-shortcodes" ),
								"param_name"  => "color_bg_main",
								"value"       => "",
								"description" => __( "Select normal background color.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "color_scheme", "value" => array( "custom" ) ),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Main text Color", "adamas-vc-shortcodes" ),
								"param_name"  => "color_txt_main",
								"value"       => "",
								"description" => __( "Select normal background color.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "color_scheme", "value" => array( "custom" ) ),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Highlight background Color", "adamas-vc-shortcodes" ),
								"param_name"  => "color_bg_highlight",
								"value"       => "",
								"description" => __( "Select highlight background color.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "color_scheme", "value" => array( "custom" ) ),
							),
							array(
								"type"        => "colorpicker",
								"class"       => "",
								"heading"     => __( "Highlight text Color", "adamas-vc-shortcodes" ),
								"param_name"  => "color_txt_highlight",
								"value"       => "",
								"description" => __( "Select highlight background color.", "adamas-vc-shortcodes" ),
								"dependency"  => Array( "element" => "color_scheme", "value" => array( "custom" ) ),
							),
							array(
								"type"             => "textfield",
								"class"            => "",
								"heading"          => __( "Package Name / Title", "adamas-vc-shortcodes" ),
								"param_name"       => "package_heading",
								"admin_label"      => true,
								"value"            => "",
								"description"      => __( "Enter the package name or table heading", "adamas-vc-shortcodes" ),
								'edit_field_class' => 'vc_col-sm-8',
							),
							array(
								"type"             => "dropdown",
								"heading"          => __( "Package Name / Title Tag", "adamas-vc-shortcodes" ),
								"param_name"       => "heading_tag",
								"value"            => array(
									__( "Default", "adamas-vc-shortcodes" ) => "h3",
									__( "H1", "adamas-vc-shortcodes" )      => "h1",
									__( "H2", "adamas-vc-shortcodes" )      => "h2",
									__( "H4", "adamas-vc-shortcodes" )      => "h4",
									__( "H5", "adamas-vc-shortcodes" )      => "h5",
									__( "H6", "adamas-vc-shortcodes" )      => "h6",
									__( "Div", "adamas-vc-shortcodes" )     => "div",
									__( "p", "adamas-vc-shortcodes" )       => "p",
									__( "span", "adamas-vc-shortcodes" )    => "span",
								),
								"description"      => __( "Default is H3", "adamas-vc-shortcodes" ),
								'edit_field_class' => 'ult-param-padding-remove vc_col-sm-4',
							),
							array(
								"type"             => "textfield",
								"class"            => "",
								"heading"          => __( "Sub Heading", "adamas-vc-shortcodes" ),
								"param_name"       => "package_sub_heading",
								"value"            => "",
								"description"      => __( "Enter short description for this package", "adamas-vc-shortcodes" ),
								'edit_field_class' => 'vc_col-sm-8',
							),
							array(
								"type"             => "dropdown",
								"heading"          => __( "Sub Heading Tag", "adamas-vc-shortcodes" ),
								"param_name"       => "sub_heading_tag",
								"value"            => array(
									__( "Default", "adamas-vc-shortcodes" ) => "h5",
									__( "H1", "adamas-vc-shortcodes" )      => "h1",
									__( "H2", "adamas-vc-shortcodes" )      => "h2",
									__( "H3", "adamas-vc-shortcodes" )      => "h3",
									__( "H4", "adamas-vc-shortcodes" )      => "h4",
									__( "H6", "adamas-vc-shortcodes" )      => "h6",
									__( "Div", "adamas-vc-shortcodes" )     => "div",
									__( "p", "adamas-vc-shortcodes" )       => "p",
									__( "span", "adamas-vc-shortcodes" )    => "span",
								),
								"description"      => __( "Default is H5", "adamas-vc-shortcodes" ),
								'edit_field_class' => 'ult-param-padding-remove vc_col-sm-4',
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Package Price", "adamas-vc-shortcodes" ),
								"param_name"  => "package_price",
								"value"       => "",
								"description" => __( "Enter the price for this package. e.g. $157", "adamas-vc-shortcodes" ),
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Price Unit", "adamas-vc-shortcodes" ),
								"param_name"  => "package_unit",
								"value"       => "",
								"description" => __( "Enter the price unit for this package. e.g. per month", "adamas-vc-shortcodes" ),
							),
							array(
								"type"             => "textarea_html",
								"class"            => "",
								"heading"          => __( "Features", "adamas-vc-shortcodes" ),
								"param_name"       => "content",
								"value"            => "",
								"description"      => __( "Create the features list using un-ordered list elements.", "adamas-vc-shortcodes" ),
								"edit_field_class" => "ult_hide_editor_fullscreen vc_col-xs-12 vc_column wpb_el_type_textarea_html vc_wrapper-param-type-textarea_html vc_shortcode-param",
							),
							array(
								"type"        => "textfield",
								"class"       => "",
								"heading"     => __( "Button Text", "adamas-vc-shortcodes" ),
								"param_name"  => "package_btn_text",
								"value"       => "",
								"description" => __( "Enter call to action button text", "adamas-vc-shortcodes" ),
							),
							array(
								"type"        => "vc_link",
								"class"       => "",
								"heading"     => __( "Button Link", "smile" ),
								"param_name"  => "package_link",
								"value"       => "",
								"description" => __( "Select / enter the link for call to action button", "adamas-vc-shortcodes" ),
							),
							array(
								"type"       => "checkbox",
								"class"      => "",
								"heading"    => "",
								"param_name" => "package_featured",
								"value"      => array( "Make this pricing box as featured" => "enable" ),
							),
							array(
								"type"        => "number",
								"class"       => "",
								"heading"     => __( "Minimum Height For Price Box", "adamas-vc-shortcodes" ),
								"param_name"  => "min_ht",
								"min"         => "",
								"suffix"      => "px",
								"description" => __( "Adjust height of your price box.", "adamas-vc-shortcodes" )

							),
							array(
								"type"        => "textfield",
								"heading"     => __( "Extra class name", "adamas-vc-shortcodes" ),
								"param_name"  => "el_class",
								"description" => __( "If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.", "adamas-vc-shortcodes" )
							),
							/* typoraphy - package */
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Package Name/Title Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "package_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper no-top-margin vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name"  => "package_name_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "package_name_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "package_name_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "package_name_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "package_name_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "package_name_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "package_name_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							/* typoraphy - sub heading */
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Sub-Heading Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "subheading_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name"  => "subheading_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "subheading_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "subheading_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "subheading_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "subheading_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "subheading_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "subheading_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							/* typoraphy - price */
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Price Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "price_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name"  => "price_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "price_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "price_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "price_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "price_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "price_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "price_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							/* typoraphy - price unit*/
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Price Unit Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "price_unit_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "smile" ),
								"param_name"  => "price_unit_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "price_unit_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "price_unit_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "price_unit_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "price_unit_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "price_unit_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "price_unit_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							/* typoraphy - feature*/
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Features Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "features_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name"  => "features_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "features_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "features_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "features_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "features_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "features_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "features_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							/* typoraphy - button */
							array(
								"type"             => "ult_param_heading",
								"text"             => __( "Button Settings", "adamas-vc-shortcodes" ),
								"param_name"       => "button_typograpy",
								"group"            => "Typography",
								"class"            => "ult-param-heading",
								'edit_field_class' => 'ult-param-heading-wrapper vc_column vc_col-sm-12',
							),
							array(
								"type"        => "ultimate_google_fonts",
								"heading"     => __( "Font Family", "adamas-vc-shortcodes" ),
								"param_name"  => "button_font_family",
								"description" => __( "Select the font of your choice.", "adamas-vc-shortcodes" ) . " " . __( "You can", "adamas-vc-shortcodes" ) . " <a target='_blank' rel='noopener' href='" . admin_url( 'admin.php?page=bsf-google-font-manager' ) . "'>" . __( "add new in the collection here", "adamas-vc-shortcodes" ) . "</a>.",
								"group"       => "Typography"
							),
							array(
								"type"       => "ultimate_google_fonts_style",
								"heading"    => __( "Font Style", "adamas-vc-shortcodes" ),
								"param_name" => "button_font_style",
								"group"      => "Typography"
							),
							// array(
							// 	"type" => "number",
							// 	"class" => "font-size",
							// 	"heading" => __("Font Size", "adamas-vc-shortcodes"),
							// 	"param_name" => "button_font_size",
							// 	"min" => 10,
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							// array(
							// 	"type" => "number",
							// 	"class" => "",
							// 	"heading" => __("Line Height", "adamas-vc-shortcodes"),
							// 	"param_name" => "button_line_height",
							// 	"value" => "",
							// 	"suffix" => "px",
							// 	"group" => "Typography"
							// ),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "font-size",
								"heading"    => __( "Font size", 'adamas-vc-shortcodes' ),
								"param_name" => "button_font_size",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "ultimate_responsive",
								"class"      => "",
								"heading"    => __( "Line Height", 'adamas-vc-shortcodes' ),
								"param_name" => "button_line_height",
								"unit"       => "px",
								"media"      => array(
									"Desktop"          => '',
									"Tablet"           => '',
									"Tablet Portrait"  => '',
									"Mobile Landscape" => '',
									"Mobile"           => '',
								),
								"group"      => "Typography",
							),
							array(
								"type"       => "colorpicker",
								"class"      => "",
								"heading"    => __( "Font Color", "adamas-vc-shortcodes" ),
								"param_name" => "button_font_color",
								"value"      => "",
								"group"      => "Typography"
							),
							array(
								'type'             => 'css_editor',
								'heading'          => __( 'Css', 'adamas-vc-shortcodes' ),
								'param_name'       => 'css_price_box',
								'group'            => __( 'Design ', 'adamas-vc-shortcodes' ),
								'edit_field_class' => 'vc_col-sm-12 vc_column no-vc-background no-vc-border creative_link_css_editor',
							),
						)// params
					) );// vc_map
			}
		}

		function ultimate_pricing_shortcode( $atts, $content = null ) {
			$design_style = '';
			extract( shortcode_atts( array(
				"design_style" => "design01",
			), $atts ) );
			$output = '';
			if ( $design_style === 'design07' ) {
				require_once plugin_dir_path( __DIR__ ) . 'pricing/pricing-' . $design_style . '.php';
			} else {
				require_once( __ULTIMATE_ROOT__ . '/templates/pricing/pricing-' . $design_style . '.php' );
			}
			$design_func = 'ult_price_generate_' . $design_style;
			$output      .= $design_func( $atts, $content );
			$is_preset   = false; //Display settings for Preset
			if ( isset( $_GET['preset'] ) ) {
				$is_preset = true;
			}
			if ( $is_preset ) {
				$text = 'array ( ';
				foreach ( $atts as $key => $att ) {
					$text .= '<br/>	\'' . $key . '\' => \'' . $att . '\',';
				}
				if ( $content != '' ) {
					$text .= '<br/>	\'content\' => \'' . $content . '\',';
				}
				$text   .= '<br/>)';
				$output .= '<pre>';
				$output .= $text;
				$output .= '</pre>';
			}

			return $output;
		}
	} // class Ultimate_Pricing_Table
	new Ultimate_Pricing_Table;
	if ( class_exists( 'WPBakeryShortCode' ) && ! class_exists( 'WPBakeryShortCode_ultimate_pricing' ) ) {
		class WPBakeryShortCode_ultimate_pricing extends WPBakeryShortCode {
		}
	}
}