<?php
/*
  Plugin Name: Adamas Custom Post Types
  Plugin URI: https://slimtemplate.net/
  Description: Adamas Theme Custom Post Types and Taxonomies
  Version: 1.0.3
  Author: SlimTemplate
  Text Domain: adamas-cpt
  Domain Path: /lang/
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'AdamasCustomPostTypes' ) ) {

	class AdamasCustomPostTypes {

		protected $option;
		private $queue;

		/**
		 * Class constructor
		 * Custom post type init and hook in tabs.
		 */
		public function __construct() {
			$post_type_link_priority = apply_filters( 'adamas_cpt_link_priority', 10 );

			add_action( 'init', array( $this, 'plugin_load_textdomain' ), 9 );
			add_action( 'init', array( $this, 'register_adamas_custom_post_types' ), 10 );
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
			add_action( 'admin_init', array( $this, 'admin_fields' ) );
			add_action( 'admin_init', array( $this, 'save_options' ) );
			add_action( 'registered_post_type', array( $this, 'registered_post_type' ), 10, 2 );
			add_filter( 'post_type_link', array( $this, 'post_type_link' ), $post_type_link_priority, 2 );
		}

		public function plugin_load_textdomain() {
			load_plugin_textdomain( 'adamas-cpt', false, basename( __DIR__ ) . '/lang/' );
		}

		/**
		 * Register Testimonials and Projects custom post types
		 * Register Project Category taxonomy
		 */
		public function register_adamas_custom_post_types() {

			$testimonial_labels = array(
				'name'               => __( 'Testimonials', 'adamas-cpt' ),
				'singular_name'      => __( 'Testimonial', 'adamas-cpt' ),
				'add_new'            => __( 'Add New', 'adamas-cpt' ),
				'add_new_item'       => __( 'Add New Testimonial', 'adamas-cpt' ),
				'edit_item'          => __( 'Edit Testimonial', 'adamas-cpt' ),
				'new_item'           => __( 'New Testimonial', 'adamas-cpt' ),
				'all_items'          => __( 'All Testimonials', 'adamas-cpt' ),
				'view_item'          => __( 'View Testimonial Item', 'adamas-cpt' ),
				'search_items'       => __( 'Search Testimonial Item', 'adamas-cpt' ),
				'not_found'          => __( 'No Testimonials Found', 'adamas-cpt' ),
				'not_found_in_trash' => __( 'No Testimonials Found in the Trash', 'adamas-cpt' ),
				'parent_item_colon'  => '',
				'menu_name'          => __( 'Testimonials', 'adamas-cpt' ),
			);
			$testimonial_args   = array(
				'labels'              => $testimonial_labels,
				'description'         => '', // TODO : Check
				'public'              => false,
				'show_ui'             => true,
				'exclude_from_search' => true,
				'show_in_nav_menus'   => false,
				'has_archive'         => false,
				'rewrite'             => false,
				'supports'            => array( 'title', 'editor', 'thumbnail' ),
				'menu_icon'           => 'dashicons-testimonial',
			);
			register_post_type( 'testimonials', $testimonial_args );

			$project_labels = array(
				'name'               => __( 'Projects', 'adamas-cpt' ),
				'singular_name'      => __( 'Project', 'adamas-cpt' ),
				'add_new'            => __( 'Add New', 'adamas-cpt' ),
				'add_new_item'       => __( 'Add New Project', 'adamas-cpt' ),
				'edit_item'          => __( 'Edit Project', 'adamas-cpt' ),
				'new_item'           => __( 'New Project', 'adamas-cpt' ),
				'all_items'          => __( 'All Projects', 'adamas-cpt' ),
				'view_item'          => __( 'View Project Item', 'adamas-cpt' ),
				'search_items'       => __( 'Search Project Item', 'adamas-cpt' ),
				'not_found'          => __( 'No Projects Found', 'adamas-cpt' ),
				'not_found_in_trash' => __( 'No Projects Found in the Trash', 'adamas-cpt' ),
				'parent_item_colon'  => '',
				'menu_name'          => __( 'Projects', 'adamas-cpt' ),
			);
			$project_args   = array(
				'labels'      => $project_labels,
				'description' => '',
				'public'      => true,
				'supports'    => array( 'title', 'editor', 'thumbnail', 'tags', 'excerpt' ),
				'has_archive' => false,
				'menu_icon'   => 'dashicons-portfolio',
				'taxonomies'  => array( 'post_tag' ),
			);
			register_post_type( 'projects', $project_args );

			$project_cat_labels = array(
				'name'              => __( 'Project Categories', 'adamas-cpt' ),
				'singular_name'     => __( 'Project Category', 'adamas-cpt' ),
				'search_items'      => __( 'Search Project Categories', 'adamas-cpt' ),
				'all_items'         => __( 'All Project Categories', 'adamas-cpt' ),
				'parent_item'       => __( 'Parent Project Category', 'adamas-cpt' ),
				'parent_item_colon' => __( 'Parent Project Category:', 'adamas-cpt' ),
				'edit_item'         => __( 'Edit Project Category', 'adamas-cpt' ),
				'update_item'       => __( 'Update Project Category', 'adamas-cpt' ),
				'add_new_item'      => __( 'Add New Project Category', 'adamas-cpt' ),
				'new_item_name'     => __( 'New Project category', 'adamas-cpt' ),
				'menu_name'         => __( 'Project categories', 'adamas-cpt' ),
			);
			$project_cat_args   = array(
				'labels'       => $project_cat_labels,
				'hierarchical' => true,

			);
			register_taxonomy( 'project_category', 'projects', $project_cat_args );

		}

		/**
		 * Adding fields to Permalink page
		 */
		public function admin_fields() {
			add_settings_section( 'adamas_cpt_projects_setting_section',
				__( 'Projects Permalinks Settings', 'adamas-cpt' ),
				array( $this, 'setting_section' ),
				'permalink'
			);

			$this->add_settings_field();
		}

		/**
		 * Additional info for setting field
		 */
		public function setting_section() {
			?>
            <p><?php _e( 'Select permalink setting.' ); ?>
				<?php _e( 'Available tags are <code>%post_id%</code>, <code>%postname%</code>, <code>%year%</code>, <code>%monthnum%</code>, <code>%day%</code>, <code>%hour%</code>, <code>%minute%</code>, <code>%second%</code>, <code>%author%</code>.' ); ?></p>

			<?php
		}

		/**
		 * Register setting field
		 */
		public function add_settings_field() {

			add_settings_field( "adamas_cpt_projects_structure",
				'Projects',
				array( $this, 'setting_field' ),
				'permalink',
				'adamas_cpt_projects_setting_section',
				"adamas_cpt_projects_structure"
			);
			register_setting( 'permalink', "adamas_cpt_projects_structure" );
		}

		/**
		 * Get example settings
		 *
		 * @param $slug
		 *
		 * @return array
		 */
		private function get_example_settings( $slug ) {
			return array(
				false,
				"/{$slug}/%post_id%",
				"/{$slug}/%postname%",
				"/{$slug}/%author%/%postname%",
				"/{$slug}/%year%/%monthnum%/%day%/%postname%/",
			);
		}

		/**
		 * Get custom post type option
		 *
		 * @param $key
		 *
		 * @return bool
		 */
		public function get( $key ) {

			$options = get_option( 'adamas_cpt_options' );

			if ( empty( $options[ $key ] ) ) {
				return false;
			}

			return $options[ $key ];
		}

		/**
		 * Check structure
		 *
		 * @return bool
		 */
		public function is_defined_structure() {
			$post_type        = 'projects';
			$post_type_object = get_post_type_object( $post_type );

			return ! empty( $post_type_object->adamas_cpt_projects_structure );
		}

		/**
		 * Get structure
		 *
		 * @return string
		 */
		public function get_structure() {
			$post_type        = 'projects';
			$post_type_object = get_post_type_object( $post_type );

			if ( $this->is_defined_structure() ) {
				return $post_type_object->adamas_cpt_projects_structure;
			}

			return trim( $this->get( "adamas_cpt_projects_structure" ), '/' );
		}

		/**
		 * Setting field
		 *
		 * @param $args
		 */
		public function setting_field( $args ) {
			global /** @var \WP_Rewrite $wp_rewrite */
			$wp_rewrite;
			$slash = '';

			if ( $wp_rewrite->use_trailing_slashes ) {
				$slash = '/';
			}

			$post_type        = 'projects';
			$post_type_object = get_post_type_object( $post_type );
			$with_front       = $post_type_object->rewrite['with_front'];
			$slug             = trim( $post_type_object->rewrite['slug'], '/' );
			if ( ! empty( $post_type_object->rewrite['original_slug'] ) ) {
				$slug = trim( $post_type_object->rewrite['original_slug'], '/' );
			}
			$sample_settings = $this->get_example_settings( $slug );

			$permastruct = $this->get_structure();

			$disabled = $this->is_defined_structure();

			?>
            <fieldset class="adamas-cpt-fieldset <?php echo ( $with_front ) ? 'with-front' : ''; ?>">
				<?php
				$checked = false;
				foreach ( $sample_settings as $sample_setting ) :
					if ( ! $checked ) {
						$checked = ( $permastruct == $sample_setting );
					}

					$dummy_tags = array(
						'%postname%' => 'sample-post',
						'%post_id%'  => '123',
						'%year%'     => date_i18n( 'Y' ),
						'%monthnum%' => date_i18n( 'm' ),
						'%day%'      => date_i18n( 'd' ),
						'%hour%'     => date_i18n( 'H' ),
						'%minute%'   => date_i18n( 'i' ),
						'%second%'   => date_i18n( 's' ),
						'%author%'   => 'author',
					);

					$permalink = str_replace( array_keys( $dummy_tags ), array_values( $dummy_tags ), $sample_setting );
					?>
                    <label>
                        <input type="radio" name="<?php echo esc_attr( $args ); ?>_select"
                               value="<?php echo esc_attr( $sample_setting ) ?>" <?php
						if ( ! $disabled ) {
							checked( $permastruct, $sample_setting );
						}
						disabled( $disabled ); ?> />
						<?php
						if ( $sample_setting ) :?>
                            <code><?php echo esc_html( home_url() ) . $this->create_permastruct( $permalink, $with_front ); ?><span class="slash"><?php echo esc_attr( $slash ); ?></span></code>
						<?php
						else : ?>
                            Default.
						<?php
						endif; ?>

                    </label>
                    <br/>
				<?php
				endforeach;
				?>
                <label>
                    <input type="radio" name="<?php echo esc_attr( $args ); ?>_select" value="custom"
						<?php checked( $checked, false ); ?>
						<?php disabled( $disabled ); ?> />
                    <code><?php echo esc_html( home_url() ) . $this->create_permastruct( '', $with_front ); ?></code>

                    <input class="regular-text code"
                           name="<?php echo esc_attr( "adamas_cpt_projects_structure" ); ?>"
                           id="<?php echo esc_attr( "adamas_cpt_projects_structure" ); ?>"
                           type="text" value="/<?php echo esc_attr( $permastruct ) ?>"
						<?php disabled( $disabled ); ?>
                    /><span class="slash"><?php echo esc_html( $slash ); ?></span>
                </label>

            </fieldset>
			<?php
		}

		/**
		 * Create permalink structure
		 *
		 * @param string $string
		 * @param bool $with_front
		 *
		 * @return string
		 */
		private function create_permastruct( $string = '', $with_front = false ) {

			/** @var \WP_Rewrite $wp_rewrite */
			global $wp_rewrite;
			$front = '';
			if ( $with_front ) {
				$front = '<span class="front">' . esc_html( substr( $wp_rewrite->front, 0, - 1 ) ) . '</span>';
			}

			return untrailingslashit( $front . esc_html( $string ) );
		}

		/**
		 * Save options
		 */
		public function save_options() {

			if ( isset( $_POST['submit'] ) and isset( $_POST['_wp_http_referer'] ) ) {

				if ( empty( $_POST['_wpnonce'] ) ) {
					return false;
				}

				if ( ! wp_verify_nonce( $_POST['_wpnonce'], 'update-permalink' ) ) {
					return false;
				}

				if ( false === strpos( $_POST['_wp_http_referer'], 'options-permalink.php' ) ) {
					return false;
				}

				$request     = $_POST;
				$new_options = $this->extract_options( $request );


				$key        = "adamas_cpt_projects_structure";
				$select_key = "adamas_cpt_projects_structure_select";

				$new_options[ $select_key ] = trim( $new_options[ $select_key ], '/' );

				if ( 'custom' != $new_options[ $select_key ] ) {
					$new_options[ $key ] = $new_options[ $select_key ];
				}

				$new_options[ $key ] = trim( $new_options[ $key ], '/' );

				unset( $new_options[ $select_key ] );
				//If Empty set default.
				if ( empty( $new_options[ $key ] ) ) {
					$new_options[ $select_key ] = false;
				}

				$old_options = get_option( 'adamas_cpt_options', array() );
				$options     = array_merge( $old_options, $new_options );
				update_option( 'adamas_cpt_options', $options );
			}
		}

		/**
		 * Extract options
		 *
		 * @param array $options
		 *
		 * @return array
		 */
		private function extract_options( array $options ) {
			$extracted = array();
			foreach ( $options as $key => $value ) {
				if ( strpos( $key, 'adamas_cpt_' ) === 0 ) {
					$extracted[ $key ] = $value;
				}
			}

			return $extracted;
		}

		/**
		 * Function after post_type project register
		 *
		 * @param $post_type
		 * @param $args
		 */
		public function registered_post_type( $post_type, $args ) {

			if ( $post_type === 'projects' ) {

				$this->override_post_type_slug();

				$this->queue[ $post_type ] = array(
					'post_type' => $post_type,
					'args'      => $args,
				);

				$this->register_rewrite_rule( $args );
			}
		}

		/**
		 * Overriding post_type projects slug
		 */
		private function override_post_type_slug() {
			$post_type = get_post_type( 'projects' );
			if ( is_object( $post_type ) && ( $slug = $this->get_front_struct() ) ) {
				$original_slug                       = $post_type->rewrite['slug'];
				$post_type->rewrite['slug']          = $slug;
				$post_type->rewrite['original_slug'] = $original_slug;
			}
		}

		/**
		 * Register rewrite rule for post_type projects
		 *
		 * @param $args
		 */
		public function register_rewrite_rule( $args ) {
			global $wp_rewrite;
			if ( '' == get_option( 'permalink_structure' ) ) {
				return;
			}

			$post_type = 'projects';

			$permastruct_args         = $args->rewrite;
			$permastruct_args['feed'] = $permastruct_args['feeds'];

			if ( $struct = $this->get_structure() ) {

				$post_type_slug = $this->get_front_struct();
				add_rewrite_tag( "%${post_type}_slug%", "(${post_type_slug})", "post_type=${post_type}&slug=" );

				$struct = str_replace( array( $post_type_slug, '%postname%' ), array(
					"%${post_type}_slug%",
					"%{$post_type}%"
				), $struct );

				//$rewrite_args['walk_dirs'] = false;
				add_permastruct( $post_type, $struct, $permastruct_args );

				$slug = $this->get_front_struct();

				if ( $slug ) {
					add_rewrite_rule( "$slug/?$", "index.php?post_type=$post_type", 'top' );

					if ( $args->rewrite['feeds'] && $wp_rewrite->feeds ) {
						$feeds = '(' . trim( implode( '|', $wp_rewrite->feeds ) ) . ')';
						add_rewrite_rule( "{$slug}/feed/$feeds/?$", "index.php?post_type=$post_type" . '&feed=$matches[1]', 'top' );
						add_rewrite_rule( "{$slug}/$feeds/?$", "index.php?post_type=$post_type" . '&feed=$matches[1]', 'top' );
					}

					if ( $args->rewrite['pages'] ) {
						add_rewrite_rule( "$slug/{$wp_rewrite->pagination_base}/?([0-9]{1,})/?$", "index.php?post_type=$post_type" . '&paged=$matches[1]', 'top' );
					}
				}
			}
		}

		/**
		 * Get front permalink structure
		 *
		 * @return string
		 */
		public function get_front_struct() {
			$structure = $this->get_structure();

			return $this->extract_front_struct( $structure );
		}

		/**
		 * Extract front permalink structure
		 *
		 * @param $structure
		 *
		 * @return string
		 */
		public function extract_front_struct( $structure ) {

			return trim( mb_substr( $structure, 0, mb_strpos( $structure, '%' ) ), '/' );
		}

		/**
		 * Enqueue script
		 *
		 * @param $hook
		 */

		public function admin_enqueue_scripts( $hook ) {
			if ( 'options-permalink.php' === $hook ) {
				wp_enqueue_script(
					'admin-adamas-cpt-script',
					plugins_url( 'js/admin-adamas-cpt-permalinks.js', __FILE__ ),
					array( 'jquery' ),
					false,
					true
				);
			}
		}

		/**
		 * Fix post_type permalink from postname to id
		 *
		 * @param $post_link
		 * @param WP_Post $post
		 *
		 * @return mixed
		 */
		public function post_type_link( $post_link, \WP_Post $post ) {

			$post_type = $post->post_type;
			if ( ! $this->get_structure() ) {
				return $post_link;
			}

			$author = '';
			if ( false !== strpos( $post_link, '%author%' ) ) {
				$authordata = get_userdata( $post->post_author );
				$author     = $authordata->user_nicename;
			}

			$post_date = strtotime( $post->post_date );

			$rewritecode    = array(
				"%${post_type}_slug%",
				'%post_id%',
				'%year%',
				'%monthnum%',
				'%day%',
				'%hour%',
				'%minute%',
				'%second%',
				'%author%',
			);
			$rewritereplace = array(
				$this->get_front_struct(),
				$post->ID,
				date( 'Y', $post_date ),
				date( 'm', $post_date ),
				date( 'd', $post_date ),
				date( 'H', $post_date ),
				date( 'i', $post_date ),
				date( 's', $post_date ),
				$author,
			);

			return str_replace( $rewritecode, $rewritereplace, $post_link );

		}
	}
}
$AdamasCustomPostTypes = new AdamasCustomPostTypes();