<?php

// Testimonials Widget

class St_Adamas_Testimonials_Widget extends WP_Widget {
	function __construct() {
		$widget_ops = array( 'description' => esc_html__( 'Displays testimonials.', 'adamas-custom-widgets' ) );
		parent::__construct( 'st_testimonials_widget', esc_html__( 'Testimonials', 'adamas-custom-widgets' ), $widget_ops );
	}

	function widget( $args, $instance ) {
		extract( $args );
		$title        = $before_title . apply_filters( 'widget_title', $instance['title'] ) . $after_title;
		$testimonials = isset( $instance['testimonials'] ) ? $instance['testimonials'] : array();

		$testimonials_args = array(
			'post_type'      => 'testimonials',
			'post_status'    => 'publish',
			'post__in'       => $testimonials,
			'posts_per_page' => - 1,
		);

		$testimonials_query = new WP_Query( $testimonials_args );

		echo $before_widget;
		if ( ! empty( $instance['title'] ) ) {
			echo esc_html( $title );
		}

		?>
        <div class="st-testimonial-widget-inner">
			<?php
			while ( $testimonials_query->have_posts() ) : $testimonials_query->the_post();
				if ( has_post_thumbnail() ) {
					$image_id  = get_post_thumbnail_id();
					$image_url = wp_get_attachment_url( $image_id, 'full' );
					$image     = ' style="background-image:url(' . esc_url( $image_url ) . ')"';
				}
				$client_occupation = get_post_meta( get_the_ID(), 'st_testimonials_position', true );
				$client_company    = get_post_meta( get_the_ID(), 'st_testimonials_company_name', true );
				?>
                <div class="st-testimonial-widget-item">
                    <div class="st-testimonial-widget-client-comment"><?php echo wp_kses_post( get_the_content() ); ?></div>
                    <div class="st-testimonial-widget-client-image"<?php echo $image; ?>></div>
                    <div class="st-testimonial-widget-client-name"><?php echo esc_attr( get_the_title() ); ?></div>
                    <div class="st-testimonial-widget-client-occupation-company"><?php echo esc_html( $client_occupation ); ?>
                        , <?php echo esc_html( $client_company ); ?></div>
                </div>
			<?php endwhile;
			wp_reset_postdata();
			?>

        </div>
		<?php echo $after_widget; ?>
		<?php
		$rtl = '';
		if ( is_rtl() ) {
			$rtl = 'rtl:true';
		}
		?>
        <script type="text/javascript">(function($) {
            'use strict';
            $(document).ready(function() {
              $('.st-testimonial-widget-inner').slick({
                rows: 0,
                slidesToShow: 1,
                slidesToScroll: 1,
                arrows: false,
                autoplay: true,
                autoplaySpeed: 5000, <?php echo esc_js( $rtl ); ?>});
            });
          })(jQuery);</script>
		<?php
	}

	function update( $new_instance, $old_instance ) {
		$instance                 = $old_instance;
		$instance['title']        = sanitize_text_field( $new_instance['title'] );
		$instance['testimonials'] = isset( $new_instance['testimonials'] ) ? $new_instance['testimonials'] : array();

		return $instance;
	}

	function form( $instance ) {
		$title        = isset( $instance['testimonials'] ) ? esc_attr( $instance['title'] ) : '';
		$testimonials = isset( $instance['testimonials'] ) ? $instance['testimonials'] : array();

		$args = array(
			'post_type'      => 'testimonials',
			'post_status'    => 'publish',
			'posts_per_page' => - 1,
		);
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'adamas-custom-widgets' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>"/></p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'testimonials' ) ); ?>"><?php esc_html_e( 'Testimonials to display:', 'adamas-custom-widgets' ); ?></label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'testimonials' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'testimonials' ) ); ?>[]" multiple>
				<?php
				$testimonials_array = get_posts( $args );
				if ( $testimonials_array ) {
					foreach ( $testimonials_array as $testimonial ) {
						echo '<option value="' . $testimonial->ID . '" ' . selected( true, in_array( $testimonial->ID, $testimonials ), false ) . '>' . $testimonial->post_title . '</option>';
					}
				}
				?>
            </select>
        </p>
        <p><?php esc_html_e( 'To select multiple testimonials, hold CTRL button and select item from the list.', 'adamas-custom-widgets' ); ?></p>
		<?php
	}
}

add_action( 'widgets_init', function () {
	register_widget( 'St_Adamas_Testimonials_Widget' );
} );