<?php
/*
 * Add-on Name: Brands Module
 */
if ( ! class_exists( 'St_Brands_Module' ) ) {
	class St_Brands_Module {
		function __construct() {
			add_shortcode( 'st_brands_module', array( $this, 'brands_module_shortcode' ) );
			add_action( 'init', array( $this, 'brands_module_init' ) );
		}

		function brands_module_shortcode( $atts ) {
			$brands_data  = $brands_layout = '';
			$company_logo = $brand_comment = $brand_comment_font = $brand_comment_font_style = $brand_comment_color = $brand_comment_font_size = $brand_comment_line_height = $brand_comment_letter_spacing = $carousel_flip_time = '';
			$el_class     = $module_animation = $animation = $animated = $inner_animated = '';

			extract( shortcode_atts( array(
				'brands_data'                  => '',
				'brands_layout'                => '',
				'brand_comment_font'           => '',
				'brand_comment_font_style'     => '',
				'brand_comment_color'          => '',
				'brand_comment_font_size'      => '',
				'brand_comment_line_height'    => '',
				'brand_comment_letter_spacing' => '',
				'carousel_flip_time'           => '',
				'module_animation'             => '',
				'el_class'                     => '',
			), $atts ) );

			$company_logo_count  = 0;
			$brand_comment_count = 0;
			$output              = '';

			if ( empty( $brands_layout ) ) {
				$brands_layout = 'carousel';
			}

			$brands_data = json_decode( urldecode( $brands_data ), true );

			$id = uniqid( 'st-brands-' );

			// Animation
			if ( $module_animation ) {
				$animated       .= ' st-animation';
				$animation      .= 'data-animation="' . esc_attr( $module_animation ) . '"';
				$inner_animated .= 'data-animated=".st-brands-item"'; // TODO : Check animation testimonial-slider and testimonial-logos-slider
			}

			// Brand comment
			$brand_comment_style = 'style="';

			if ( $brand_comment_font !== '' ) {
				$brand_comment_font_family = function_exists( 'get_ultimate_font_family' ) ? get_ultimate_font_family( $brand_comment_font ) : '';
				if ( $brand_comment_font_family !== '' ) {
					$brand_comment_style .= 'font-family:\'' . $brand_comment_font_family . '\';';
				}
			}

			if ( $brand_comment_font_style !== '' ) {
				$brand_comment_style .= esc_attr( $brand_comment_font_style );
			}

			if ( is_numeric( $brand_comment_font_size ) ) {
				$brand_comment_font_size = 'desktop:' . $brand_comment_font_size . 'px;';
			}

			if ( is_numeric( $brand_comment_line_height ) ) {
				$brand_comment_line_height = 'desktop:' . $brand_comment_line_height . 'px;';
			}

			$brand_comment_args = array(
				'target'      => '#' . $id . '-comments .st-brand-comment',
				'media_sizes' => array(
					'font-size'   => $brand_comment_font_size,
					'line-height' => $brand_comment_line_height,
				),
			);

			$brand_comment_responsive = get_ultimate_vc_responsive_media_css( $brand_comment_args );

			$brand_comment_style .= $brand_comment_letter_spacing !== '' ? 'letter-spacing:' . esc_attr( $brand_comment_letter_spacing ) . 'px;' : '';
			$brand_comment_style .= $brand_comment_color !== '' ? 'color:' . esc_attr( $brand_comment_color ) . ';' : '';
			$brand_comment_style .= '"';


			$carousel = '';
			$carousel .= '<div class="st-brands-wrapper carousel"><div id="' . esc_attr( $id ) . '" class="st-brands-logo-slider ' . esc_attr( $el_class ) . ' ' . esc_attr( $animated ) . '" ' . $animation . '>';
			if ( isset( $brands_data ) ) {
				foreach ( $brands_data as $brands_datas ) {
					$company_logo_count ++;
					if ( isset( $brands_datas['link'] ) ) {
						$link = $brands_datas['link'];
						$href = vc_build_link( $link );
						if ( $href['url'] != '' ) {
							$url         = ( isset( $href['url'] ) && $href['url'] !== '' ) ? $href['url'] : '';
							$target      = ( isset( $href['target'] ) && $href['target'] !== '' ) ? "target='" . esc_attr( trim( $href['target'] ) ) . "'" : '';
							$link_title  = ( isset( $href['title'] ) && $href['title'] !== '' ) ? "title='" . esc_attr( $href['title'] ) . "'" : '';
							$rel         = ( isset( $href['rel'] ) && $href['rel'] !== '' ) ? "rel='" . esc_attr( $href['rel'] ) . "'" : '';
							$link_prefix = '<a class="st-brand-link" href="' . esc_url( $url ) . '" ' . $target . ' ' . $rel . ' ' . $link_title . '>';
							$link_sufix  = '</a>';
						}
					} else {
						$link_prefix = $link_sufix = '';
					}
					if ( isset( $brands_datas['company_logo'] ) ) {
						$brand_img      = wp_get_attachment_image_src( $brands_datas['company_logo'], 'full' );
						$brand_img_alt  = strip_tags( get_post_meta( $brands_datas['company_logo'], '_wp_attachment_image_alt', true ) );
						$brand_img_link = $brand_img[0];
						$carousel       .= '<div class="st-brand-logo">' . $link_prefix . '<img src="' . esc_url( $brand_img_link ) . '" alt="' . esc_attr( $brand_img_alt ) . '">' . $link_sufix . '</div>';
					}
				}
			}
			$carousel .= '</div>'; // st-brands-logo-slider

			if ( isset( $brands_data[0]['brand_comment'] ) ) {
				$carousel .= '<div class="st-brand-pointer"></div>';
				$carousel .= '<div id="' . esc_attr( $id ) . '-comments" class="st-brands-comments-slider">';
				foreach ( $brands_data as $brands_datas ) {
					if ( isset( $brands_datas['brand_comment'] ) ) {
						$carousel .= '<div class="st-brand-comment ult-responsive" ' . $brand_comment_style . ' ' . $brand_comment_responsive . '>' . wp_kses_post( $brands_datas['brand_comment'] ) . '</div>';
					}
				}
				$carousel .= '</div>'; // st-brands-comments-slider
			}
			$carousel .= '</div>'; // st-brands-wrapper

			wp_enqueue_script( 'slick' );

			$rtl = '';
			if ( is_rtl() ) {
				$rtl = ',rtl:true';
			}

			$carousel_flip = '';
			if ( $carousel_flip_time != '' ) {
				$carousel_flip = ',autoplay:true,autoplaySpeed:' . esc_js( $carousel_flip_time ) * 1000;
			}


			$carousel .= '<script type="text/javascript">';
			$carousel .= '(function($){';
			$carousel .= '"use strict";';
			if ( $company_logo_count == 1 || $company_logo_count == 2 ) {
				$carousel .= '$("head").append("<style>.st-brands-wrapper .st-brands-logo-slider .slick-list{width:160px;overflow:hidden}</style>");';
			} else if ( $company_logo_count == 3 || $company_logo_count == 4 ) {
				$carousel .= '$("head").append("<style>.st-brands-wrapper .st-brands-logo-slider .slick-list{width:500px;overflow:hidden}</style>");';
			}
			$carousel .= '$(document).ready(function(){';
			if ( isset( $brands_data[0]['brand_comment'] ) ) {
				$carousel .= '$("#' . esc_js( $id ) . '").slick({rows:0,slidesToShow:3,slidesToScroll:1,asNavFor: "#' . esc_js( $id ) . '-comments",swipeToSlide:false,centerMode:true,focusOnSelect:true,responsive:[{breakpoint:767,settings:{slidesToShow:1}}]' . $carousel_flip . '' . $rtl . '});$("#' . esc_js( $id ) . '-comments").slick({slidesToShow:1,slidesToScroll:1,arrows:false,asNavFor: "#' . esc_js( $id ) . '"' . $rtl . '});';
			} else {
				$carousel .= '$("#' . esc_js( $id ) . '").slick({rows:0,slidesToShow:3,slidesToScroll:1,swipeToSlide:false,centerMode:true,focusOnSelect:true,responsive:[{breakpoint:767,settings:{slidesToShow:1}}]' . $carousel_flip . '' . $rtl . '});';
			}
			$carousel .= '})';
			$carousel .= '})(jQuery);';
			$carousel .= '</script>';

			$grid = '';
			$grid .= '<div class="st-brands-wrapper grid ' . esc_attr( $el_class ) . ' ' . esc_attr( $animated ) . '" id="' . esc_attr( $id ) . '" ' . $inner_animated . ' ' . $animation . '>';
			$grid .= '<div class="st-brands-wrapper-inner">';
			if ( isset( $brands_data ) ) {
				foreach ( $brands_data as $brands_datas ) {
					if ( isset( $brands_datas['link'] ) ) {
						$link = $brands_datas['link'];
						$href = vc_build_link( $link );
						if ( $href['url'] != '' ) {
							$url         = ( isset( $href['url'] ) && $href['url'] !== '' ) ? $href['url'] : '';
							$target      = ( isset( $href['target'] ) && $href['target'] !== '' ) ? "target='" . esc_attr( trim( $href['target'] ) ) . "'" : '';
							$link_title  = ( isset( $href['title'] ) && $href['title'] !== '' ) ? "title='" . esc_attr( $href['title'] ) . "'" : '';
							$rel         = ( isset( $href['rel'] ) && $href['rel'] !== '' ) ? "rel='" . esc_attr( $href['rel'] ) . "'" : '';
							$link_prefix = '<a class="st-brand-link" href="' . esc_url( $url ) . '" ' . $target . ' ' . $rel . ' ' . $link_title . '>';
							$link_sufix  = '</a>';
						}
					} else {
						$link_prefix = $link_sufix = '';
					}
					$brand_img      = wp_get_attachment_image_src( $brands_datas['company_logo'], 'full' );
					$brand_img_alt  = strip_tags( get_post_meta( $brands_datas['company_logo'], '_wp_attachment_image_alt', true ) );
					$brand_img_link = $brand_img[0];

					$brand_comment = isset( $brands_datas['brand_comment'] ) ? $brands_datas['brand_comment'] : '';

					$grid .= '<div class="st-brands-item">' . $link_prefix . '<div class="st-brands-item-inner">';
					$grid .= '<div class="st-brand-logo"><img src="' . esc_url( $brand_img_link ) . '" alt="' . esc_attr( $brand_img_alt ) . '" /></div>';
					$grid .= '<div><div class="st-brand-comment ult-responsive" ' . $brand_comment_style . ' ' . $brand_comment_responsive . '>' . wp_kses_post( $brand_comment ) . '</div></div>';;
					$grid .= '</div>' . $link_sufix . '</div>'; // st-brands-item-inner, st-brands-item
				}
			}
			$grid .= '</div>'; // st-brands-wrapper-inner
			$grid .= '</div>'; // st-brands-wrapper

			if ( strcmp( $brands_layout, 'carousel' ) === 0 ) {
				$output .= $carousel;
			} else {
				$output .= $grid;
			}

			return $output;
		}

		function brands_module_init() {
			if ( function_exists( 'vc_map' ) ) {
				vc_map( array(
					'name'        => __( 'Brands', 'adamas-vc-shortcodes' ),
					'base'        => 'st_brands_module',
					'icon'        => get_template_directory_uri() . '/assets/images/shortcode_icons/brands.png',
					'category'    => __( 'ST Addons', 'adamas-vc-shortcodes' ),
					'description' => __( 'Logos with description', 'adamas-vc-shortcodes' ),
					'params'      => array(
						array(
							'type'        => 'dropdown',
							'param_name'  => 'brands_layout',
							'heading'     => __( 'Appearance', 'adamas-vc-shortcodes' ),
							'value'       => array(
								__( 'Carousel', 'adamas-vc-shortcodes' ) => 'carousel',
								__( 'Grid', 'adamas-vc-shortcodes' )     => 'grid'
							),
							'description' => __( 'Please, select type of module appearance.', 'adamas-vc-shortcodes' ),
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Carousel Flip Time', 'adamas-vc-shortcodes' ),
							'param_name'  => 'carousel_flip_time',
							'suffix'      => 'seconds',
							'description' => __( 'Leave this field empty to disable carousel flip.', 'adamas-vc-shortcodes' ),
							'value'       => '5',
							'dependency'  => Array( 'element' => 'brands_layout', 'value' => array( 'carousel' ) ),
						),
						array(
							'type'        => 'param_group',
							'param_name'  => 'brands_data',
							'description' => __( 'Add brands here.', 'adamas-vc-shortcodes' ),
							'value'       => urlencode( json_encode( array(
								array(
									'company_logo'  => '',
									'brand_comment' => '',
									'link'          => '',
								)
							) ) ),
							'params'      => array(
								array(
									'type'       => 'attach_image',
									'heading'    => __( 'Company logo', 'adamas-vc-shortcodes' ),
									'param_name' => 'company_logo',
								),
								array(
									'type'       => 'vc_link',
									'heading'    => __( 'Link', 'adamas-vc-shortcodes' ),
									'param_name' => 'link',
								),
								array(
									'type'        => 'textarea',
									'heading'     => __( 'Brand comment', 'adamas-vc-shortcodes' ),
									'param_name'  => 'brand_comment',
									'value'       => '',
									'description' => '',
								),
							),
						),
						// Animation
						array(
							'type'        => 'dropdown',
							'class'       => '',
							'heading'     => __( 'Animation', 'adamas-vc-shortcodes' ),
							'param_name'  => 'module_animation',
							'value'       => st_adamas_animations_list(),
							'description' => __( 'Select appearance animation for this element.', 'adamas-vc-shortcodes' ),
						),

						// Brand comment typography
						array(
							'type'        => 'ultimate_google_fonts',
							'heading'     => __( 'Brand comment font family', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_font',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_google_fonts_style',
							'heading'     => __( 'Brand comment font style', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_font_style',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'colorpicker',
							'heading'     => __( 'Brand comment font color', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_color',
							'value'       => '',
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Brand comment font size', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_font_size',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'ultimate_responsive',
							'class'       => 'font-size',
							'heading'     => __( 'Brand comment line height', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_line_height',
							'unit'        => 'px',
							'media'       => array(
								"Desktop"          => '',
								"Tablet"           => '',
								"Tablet Portrait"  => '',
								"Mobile Landscape" => '',
								"Mobile"           => '',
							),
							'description' => '',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'number',
							'heading'     => __( 'Brand comment letter spacing', 'adamas-vc-shortcodes' ),
							'param_name'  => 'brand_comment_letter_spacing',
							'value'       => '',
							'description' => '',
							'suffix'      => 'px',
							'group'       => 'Typography',
						),
						array(
							'type'        => 'textfield',
							'heading'     => __( 'Extra class name', 'adamas-vc-shortcodes' ),
							'param_name'  => 'el_class',
							'description' => __( 'If you wish to style particular content element differently, then use this field to add a class name and then refer to it in your css file.', 'adamas-vc-shortcodes' )
						),
					)
				) );
			}
		}
	}

	$st_brands_module = new St_Brands_Module;
	if ( class_exists( 'WPBakeryShortCode' ) ) {
		class WPBakeryShortCode_st_brands_module extends WPBakeryShortCode {
		}
	}
}