<?php
/*
 * Adamas theme functions
 */

// Define theme name
define( 'ST_ADAMAS_THEME_NAME', 'adamas' );

if ( ! isset( $content_width ) ) {
	$content_width = 1200;
}

add_action( 'after_setup_theme', 'st_adamas_theme_init' );

if ( ! function_exists( 'st_adamas_theme_init' ) ) {
	function st_adamas_theme_init() {

		// Theme translation availability
		load_theme_textdomain( 'adamas', get_template_directory() . '/lang' );

		// Including theme components
		require_once get_theme_file_path( '/includes/includes.php' );

		// Enqueues scripts and styles
		add_action( 'wp_enqueue_scripts', 'st_adamas_styles_scripts_init' );

		// Enqueues admin styles
		add_action( 'admin_enqueue_scripts', 'st_adamas_admin_css_init' );

		//	Adds prettyPhoto rel to all content images
		add_filter( 'the_content', 'st_adamas_autoadd_rel_prettyPhoto' );
		add_filter( 'wp_get_attachment_link', 'st_adamas_prettyadd', 10, 6 );

		// New Excerpt Length
		add_filter( 'excerpt_length', 'st_adamas_excerpt_length', 999 );

		// Modifying default "Read more"
		add_filter( 'excerpt_more', 'st_adamas_excerpt_more' );

		// Adds class to next/previous links
		add_filter( 'next_posts_link_attributes', 'st_adamas_next_posts_link_attributes' );
		add_filter( 'previous_posts_link_attributes', 'st_adamas_previous_posts_link_attributes' );

		// Switch default core markup for search form, comment form, comments, galleries, captions and widgets to output valid HTML5.
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
			'widgets',
			'script',
		) );

		// Title-tag theme support
		add_theme_support( 'title-tag' );

		// Adds post thumbnails
		add_theme_support( 'post-thumbnails' );

		// Adds post formats
		add_theme_support( 'post-formats', array( 'gallery', 'video', 'quote', 'audio' ) );

		// WooCommerce support
		st_adamas_woocommerce_support();

		// Registers menus
		register_nav_menus( array(
			'primary_navigation' => esc_html__( 'Primary navigation', 'adamas' ),
		) );

		add_theme_support( 'automatic-feed-links' );

		add_post_type_support( 'page', 'excerpt' );

		st_adamas_image_setup();

		st_adamas_mega_menu_init();
		add_filter( 'wp_nav_menu_args', 'st_adamas_mega_menu_walker' );

		// Default block styles
		add_theme_support( 'wp-block-styles' );

		add_theme_support( 'editor-styles' );

		// Visual Composer Theme Integration
		if ( class_exists( 'Vc_Manager', false ) ) {
			if ( function_exists( 'vc_set_as_theme' ) ) {
				vc_set_as_theme();
			}

			// Set post types for VC
			if ( function_exists( 'vc_set_default_editor_post_types' ) ) {
				vc_set_default_editor_post_types( array( 'page', 'post', 'projects' ) );
			}
		}
	}
}

// Body Class Filter
function st_adamas_body_class( $classes ) {
	global $st_adamas;
	$boxed_layout = '';

	if ( isset( $st_adamas['boxed_body'] ) && ( $st_adamas['boxed_body'] ) == 1 ):
		$boxed_layout .= 'boxed';
	endif;

	return array_merge( $classes, array( $boxed_layout ) );
}

add_filter( 'body_class', 'st_adamas_body_class' );

// Changing Default Image Link Type and Size
if ( ! function_exists( 'st_adamas_image_setup' ) ) {
	function st_adamas_image_setup() {
		update_option( 'image_default_link_type', 'none' );
		update_option( 'image_default_size', 'large' );
	}
}

if ( ! function_exists( 'st_adamas_cutString' ) ) {
	function st_adamas_cutString( $string, $maxlen = 100 ) {
		$len    = ( mb_strlen( $string ) > $maxlen ) ? mb_strripos( mb_substr( $string, 0, $maxlen ), ' ' ) : $maxlen;
		$cutStr = mb_substr( $string, 0, $len );

		return ( mb_strlen( $string ) > $maxlen ) ? $cutStr . '...' : $cutStr;
	}
}

// WooCommerce Support
if ( ! function_exists( 'st_adamas_woocommerce_support' ) ) {
	function st_adamas_woocommerce_support() {
		add_theme_support( 'woocommerce' );
		if ( class_exists( 'woocommerce' ) ) {
			require_once get_theme_file_path( '/includes/woocommerce.php' );
		}
	}
}

if ( ! function_exists( 'st_adamas_remove_vc_shortcodes' ) ) {
	function st_adamas_remove_vc_shortcodes( $content ) {
		$patterns     = "/\[[\/]?vc_[^\]]*\]/";
		$replacements = "";

		return preg_replace( $patterns, $replacements, $content );
	}
}