<?php
/*
 * Additional Theme Options
 */

// New Default Excerpt Length
function st_adamas_excerpt_length( $length ) {
	return 30;
}

// Modifying default "Read more"
function st_adamas_excerpt_more( $more ) {
	return '...';
}

// Add class to next/previous links
function st_adamas_next_posts_link_attributes() {
	return 'class="next"';
}

function st_adamas_previous_posts_link_attributes() {
	return 'class="previous"';
}

// Add prettyPhoto rel to all images
function st_adamas_autoadd_rel_prettyPhoto( $content ) {
	global $post;
	$pattern     = "/(<a(?![^>]*?rel=['\"]prettyPhoto.*)[^>]*?href=['\"][^'\"]+?\.(?:bmp|gif|jpg|jpeg|png)['\"][^\>]*)>/i";
	$replacement = '$1 rel="prettyPhoto[' . $post->ID . ']">';
	$content     = preg_replace( $pattern, $replacement, $content );

	return $content;
}

//
function st_adamas_prettyadd( $content, $id, $size, $permalink, $icon, $text ) {
	if ( $permalink ) {
		return $content;
	}
	$content = preg_replace( "/<a/", "<a rel=\"prettyPhoto[slides]\"", $content, 1 );

	return $content;
}

function st_adamas_breadcrumbs() {

	global $st_adamas, $post;

	$protocol = 'http:';
	if ( is_ssl() ) {
		$protocol = 'https:';
	}

	if ( isset( $st_adamas['projects_archive'] ) && ! empty( $st_adamas['projects_archive'] ) ) {
		$projects_archive      = get_post( $st_adamas['projects_archive'] );
		$projects_archive_name = esc_html( $projects_archive->post_title );
		$projects_archive_slug = $projects_archive->post_name;
	} else {
		$projects_archive_slug = 'projects';
		$projects_archive_name = esc_html__( 'Projects', 'adamas' );
	}

	/* === OPTIONS === */
	$text['home']     = esc_html__( 'Home', 'adamas' );
	$text['category'] = '%s';
	$text['search']   = esc_html__( 'Search Results for "%s"', 'adamas' );
	$text['tag']      = esc_html__( 'Posts Tagged "%s"', 'adamas' );
	$text['author']   = esc_html__( 'Articles Posted by %s', 'adamas' );
	$text['404']      = esc_html__( 'Error 404', 'adamas' );
	$text['page']     = esc_html__( 'Page %s', 'adamas' );
	$text['cpage']    = esc_html__( 'Comment Page %s', 'adamas' );

	$wrap_before = '<div itemscope itemtype="' . $protocol . '//schema.org/BreadcrumbList" class="breadcrumbs">';
	$wrap_after  = '</div>';
	$sep         = '<span class="sep">›</span>';
	$before      = '<span itemprop="itemListElement" itemscope itemtype="' . $protocol . '//schema.org/ListItem" class="current">';
	$after       = '</span>';

	$before_current   = '<span itemprop="name">';
	$after_current    = '</span>';
	$position_current = '<meta itemprop="position" content="%s" />';

	$show_on_home   = 0;
	$show_home_link = 1;
	$show_current   = 1;
	$show_last_sep  = 1;
	/* === END OF OPTIONS === */

	$home_url  = home_url( '/' );
	$link      = '<span itemprop="itemListElement" itemscope itemtype="' . $protocol . '//schema.org/ListItem">';
	$link      .= '<a itemprop="item" href="%1$s" class="breadcrumbs__link"><span itemprop="name">%2$s</span></a>';
	$link      .= '<meta itemprop="position" content="%3$s" />';
	$link      .= '</span>';
	$parent_id = ( $post ) ? $post->post_parent : '';
	$home_link = sprintf( $link, $home_url, $text['home'], 1 );

	$link_kses        = array(
		'a'    => array( 'class' => array(), 'itemprop' => array(), 'itemscope' => array(), 'itemtype' => array(), 'href' => array() ),
		'span' => array( 'itemprop' => array(), 'itemscope' => array(), 'itemtype' => array(), 'class' => array() ),
		'meta' => array( 'itemprop' => array(), 'content' => array() ),
	);
	$wrap_before_kses = array(
		'div'  => array( 'class' => array(), 'itemscope' => array(), 'itemtype' => array(), 'itemprop' => array() ),
		'span' => array( 'itemprop' => array(), 'itemscope' => array(), 'itemtype' => array(), 'class' => array() ),
	);
	$span_kses        = array(
		'span' => array( 'itemprop' => array(), 'itemscope' => array(), 'itemtype' => array(), 'class' => array() ),
	);

	if ( is_front_page() ) {

		if ( $show_on_home ) {
			echo wp_kses( $wrap_before, $wrap_before_kses ) . $home_link . $wrap_after;
		}

	} else {

		$position = 0;

		echo wp_kses( $wrap_before, $wrap_before_kses );

		if ( $show_home_link ) {
			++ $position;
			echo wp_kses( $home_link, $link_kses );
		}

		if ( is_home() && get_option( 'page_for_posts' ) ) {
			$page_for_posts = get_option( 'page_for_posts', true );
			if ( $page_for_posts ) {
				$blog_page_title = get_the_title( $page_for_posts );
			} else {
				$blog_page_title = esc_html__( 'Latest Posts', 'adamas' );
			}
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			++ $position;
			echo wp_kses( $before, $span_kses ) . $before_current . esc_html( $blog_page_title ) . $after_current . sprintf( $position_current, $position ) . $after;
		}

		if ( is_category() ) {
			$parents = get_ancestors( get_query_var( 'cat' ), 'category' );
			foreach ( array_reverse( $parents ) as $cat ) {
				++ $position;
				if ( $position > 1 ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_category_link( $cat ), get_cat_name( $cat ), $position );
			}
			if ( get_query_var( 'paged' ) ) {
				++ $position;
				$cat = get_query_var( 'cat' );
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_category_link( $cat ), get_cat_name( $cat ), $position );

				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			} else {
				if ( $show_current ) {
					if ( $position >= 1 ) {
						echo wp_kses( $sep, $span_kses );
					}
					++ $position;
					echo wp_kses( $before, $span_kses ) . $before_current . sprintf( $text['category'], single_cat_title( '', false ) ) . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			}

		} elseif ( is_search() ) {
			if ( get_query_var( 'paged' ) ) {
				++ $position;
				if ( $show_home_link ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, $home_url . '?s=' . get_search_query(), sprintf( $text['search'], get_search_query() ), $position );
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			} else {
				if ( $show_current ) {
					if ( $position >= 1 ) {
						echo wp_kses( $sep, $span_kses );
					}
					++ $position;
					echo wp_kses( $before, $span_kses ) . $before_current . sprintf( $text['search'], get_search_query() ) . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			}

		} elseif ( is_year() ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $before, $span_kses ) . $before_current . get_the_time( 'Y' ) . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_home_link && $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_month() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			++ $position;
			echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ), $position );
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_time( 'F' ) . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_day() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			++ $position;
			echo sprintf( $link, get_year_link( get_the_time( 'Y' ) ), get_the_time( 'Y' ), $position ) . $sep;
			++ $position;
			echo sprintf( $link, get_month_link( get_the_time( 'Y' ), get_the_time( 'm' ) ), get_the_time( 'F' ), $position );
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_time( 'd' ) . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_single() && ! is_attachment() ) {

			// Projects
			if ( get_post_type() === 'projects' ) {
				++ $position;
				echo wp_kses( $sep, $span_kses );
				printf( $link, $home_url . $projects_archive_slug . '/', $projects_archive_name, $position );
				if ( $show_current ) {
					++ $position;
					echo wp_kses( $sep, $span_kses ) . $before . $before_current . esc_html( get_the_title() ) . $after_current . sprintf( $position_current, $position ) . $after;
				}

				// WooCommerce Single Product
			} elseif ( class_exists( 'WooCommerce' ) && is_product() ) {
				if ( '' !== get_option( 'woocommerce_shop_page_id' ) ) {
					++ $position;
					$shop_id = get_option( 'woocommerce_shop_page_id' );
					echo wp_kses( $sep, $span_kses );
					printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ), $position );
				}

				if ( $terms = wc_get_product_terms( $post->ID, 'product_cat', array(
					'orderby' => 'parent',
					'order'   => 'DESC'
				) ) ) {
					$main_term = apply_filters( 'woocommerce_breadcrumb_main_term', $terms[0], $terms );
					$ancestors = get_ancestors( $main_term->term_id, 'product_cat' );
					$ancestors = array_reverse( $ancestors );

					foreach ( $ancestors as $ancestor ) {
						++ $position;
						$ancestor = get_term( $ancestor, 'product_cat' );
						echo wp_kses( $sep, $span_kses );
						printf( $link, get_term_link( $ancestor ), $ancestor->name, $position );
					}
					echo wp_kses( $sep, $span_kses );
					++ $position;
					printf( $link, get_term_link( $main_term ), $main_term->name, $position );
				}

				if ( $show_current ) {
					++ $position;
					echo wp_kses( $sep, $span_kses ) . $before . $before_current . esc_html( get_the_title() ) . $after_current . sprintf( $position_current, $position ) . $after;
				}

				// Custom post type
			} elseif ( get_post_type() !== 'post' ) {
				++ $position;
				$post_type = get_post_type_object( get_post_type() );
				if ( $position > 1 ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_post_type_archive_link( $post_type->name ), $post_type->labels->name, $position );
				if ( $show_current ) {
					++ $position;
					echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_title() . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			} else {

				// Post
				$page_for_posts = get_option( 'page_for_posts', true );
				if ( $page_for_posts ) {
					$blog_page_title = get_the_title( $page_for_posts );
				} else {
					$blog_page_title = esc_html__( 'Latest Posts', 'adamas' );
				}

				if ( get_option( 'page_for_posts' ) ) {
					++ $position;
					echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_permalink( get_option( 'page_for_posts' ) ), $blog_page_title, $position );
				}

				$cat       = get_the_category();
				$catID     = $cat[0]->cat_ID;
				$parents   = get_ancestors( $catID, 'category' );
				$parents   = array_reverse( $parents );
				$parents[] = $catID;
				foreach ( $parents as $cat ) {
					++ $position;
					if ( $position > 1 ) {
						echo wp_kses( $sep, $span_kses );
					}
					echo sprintf( $link, get_category_link( $cat ), get_cat_name( $cat ), $position );
				}
				if ( get_query_var( 'cpage' ) ) {
					++ $position;
					echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_permalink(), get_the_title(), $position );
					++ $position;
					echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( $text['cpage'], get_query_var( 'cpage' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
				} else {
					if ( $show_current ) {
						++ $position;
						echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_title() . $after_current . sprintf( $position_current, $position ) . $after;
					} elseif ( $show_last_sep ) {
						echo wp_kses( $sep, $span_kses );
					}
				}
			}

			// WooCommerce Shop
		} elseif ( class_exists( 'WooCommerce' ) && is_shop() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $before, $span_kses ) . $before_current . esc_html( woocommerce_page_title( false ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			}
			// WooCommerce Product Category
		} elseif ( class_exists( 'WooCommerce' ) && is_product_category() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}

			++ $position;
			$shop_id = get_option( 'woocommerce_shop_page_id' );
			printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ), $position );

			$term = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );

			$ancestors = get_ancestors( $term->term_id, 'product_cat' );
			$ancestors = array_reverse( $ancestors );

			foreach ( $ancestors as $ancestor ) {
				++ $position;
				$ancestor = get_term( $ancestor, 'product_cat' );
				echo wp_kses( $sep, $span_kses );
				printf( $link, get_term_link( $ancestor ), $ancestor->name, $position );
			}

			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . esc_html( $term->name ) . $after_current . sprintf( $position_current, $position ) . $after;
			}
			// WooCommerce Product Tag
		} elseif ( class_exists( 'WooCommerce' ) && is_product_tag() ) {
			if ( $show_home_link ) {
				echo wp_kses( $sep, $span_kses );
			}
			++ $position;
			$shop_id = get_option( 'woocommerce_shop_page_id' );
			$term    = get_term_by( 'slug', get_query_var( 'term' ), get_query_var( 'taxonomy' ) );
			printf( $link, get_permalink( $shop_id ), esc_html( get_the_title( $shop_id ) ), $position );
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( esc_html__( 'Products Tagged "%s"', 'adamas' ), esc_html( $term->name ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			}

		} elseif ( is_post_type_archive() ) {
			$post_type = get_post_type_object( get_post_type() );
			if ( get_query_var( 'paged' ) ) {
				++ $position;
				if ( $position > 1 ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_post_type_archive_link( $post_type->name ), $post_type->label, $position );
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			} else {
				if ( $show_home_link && $show_current ) {
					echo wp_kses( $sep, $span_kses );
				}
				if ( $show_current ) {
					++ $position;
					echo wp_kses( $before, $span_kses ) . $before_current . $post_type->label . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_home_link && $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			}

		} elseif ( is_attachment() ) {
			$parent    = get_post( $parent_id );
			$cat       = get_the_category( $parent->ID );
			$catID     = $cat[0]->cat_ID;
			$parents   = get_ancestors( $catID, 'category' );
			$parents   = array_reverse( $parents );
			$parents[] = $catID;
			foreach ( $parents as $cat ) {
				++ $position;
				if ( $position > 1 ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_category_link( $cat ), get_cat_name( $cat ), $position );
			}
			++ $position;
			echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_permalink( $parent ), $parent->post_title, $position );
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_title() . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_page() && ! $parent_id ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $before, $span_kses ) . $before_current . get_the_title() . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_home_link && $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_page() && $parent_id ) {
			$parents = get_post_ancestors( get_the_ID() );
			foreach ( array_reverse( $parents ) as $pageID ) {
				++ $position;
				if ( $position > 1 ) {
					echo wp_kses( $sep, $span_kses );
				}
				echo sprintf( $link, get_page_link( $pageID ), get_the_title( $pageID ), $position );
			}
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . get_the_title() . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( is_tag() ) {
			if ( get_query_var( 'paged' ) ) {
				++ $position;
				$tagID = get_query_var( 'tag_id' );
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_tag_link( $tagID ), single_tag_title( '', false ), $position );
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before . $before_current . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			} else {
				if ( $show_home_link && $show_current ) {
					echo wp_kses( $sep, $span_kses );
				}
				if ( $show_current ) {
					++ $position;
					echo wp_kses( $before, $span_kses ) . $before_current . sprintf( $text['tag'], single_tag_title( '', false ) ) . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_home_link && $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			}

		} elseif ( is_author() ) {
			$author = get_userdata( get_query_var( 'author' ) );
			if ( get_query_var( 'paged' ) ) {
				++ $position;
				echo wp_kses( $sep, $span_kses ) . sprintf( $link, get_author_posts_url( $author->ID ), sprintf( $text['author'], $author->display_name ), $position );
				++ $position;
				echo wp_kses( $sep, $span_kses ) . $before_current . $before . sprintf( $text['page'], get_query_var( 'paged' ) ) . $after_current . sprintf( $position_current, $position ) . $after;
			} else {
				if ( $show_home_link && $show_current ) {
					echo wp_kses( $sep, $span_kses );
				}
				if ( $show_current ) {
					++ $position;
					echo wp_kses( $before, $span_kses ) . $before_current . sprintf( $text['author'], $author->display_name ) . $after_current . sprintf( $position_current, $position ) . $after;
				} elseif ( $show_home_link && $show_last_sep ) {
					echo wp_kses( $sep, $span_kses );
				}
			}

		} elseif ( is_404() ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			if ( $show_current ) {
				++ $position;
				echo wp_kses( $before, $span_kses ) . $before_current . $text['404'] . $after_current . sprintf( $position_current, $position ) . $after;
			} elseif ( $show_last_sep ) {
				echo wp_kses( $sep, $span_kses );
			}

		} elseif ( has_post_format() && ! is_singular() ) {
			if ( $show_home_link && $show_current ) {
				echo wp_kses( $sep, $span_kses );
			}
			echo get_post_format_string( get_post_format() );
		}

		echo wp_kses( $wrap_after, $wrap_before_kses );

	}

}

// Post pagination
function st_adamas_link_pages() {
	wp_link_pages( array(
		'before'      => '<nav class="post-pagination">',
		'after'       => '</nav>',
		'link_before' => '<span>',
		'link_after'  => '</span>',
	) );
}

// Default pagination
function st_adamas_pagination() {
	global $wp_query;

	$big = 999999999;

	$paginate_links = paginate_links( array(
		'base'      => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
		'current'   => max( 1, get_query_var( 'paged' ) ),
		'total'     => $wp_query->max_num_pages,
		'mid_size'  => 2,
		'end_size'  => 2,
		'prev_text' => esc_html__( 'Previous', 'adamas' ),
		'next_text' => esc_html__( 'Next', 'adamas' ),
	) );

	if ( $paginate_links ) {
		echo '<div class="pagination">';
		echo wp_kses_post( $paginate_links );
		echo '</div>';
	}
}

// "Load more" pagination
function st_adamas_ajax_pagination() {
	global $wp_query;

	$max   = $wp_query->max_num_pages;
	$page  = get_query_var( 'paged' );
	$paged = ( $page > 1 ) ? $page : 1;

	wp_enqueue_script( 'st_adamas_blog_ajax_pagination', get_template_directory_uri() . '/assets/js/blog-ajax-pagination.js', array( 'jquery' ), false, true );

	wp_localize_script(
		'st_adamas_blog_ajax_pagination',
		'st_ajax_data',
		array(
			'startPage' => $paged,
			'maxPages'  => $max,
			'nextLink'  => next_posts( $max, false ),
			'container' => '.blog-articles',
			'loadMore'  => esc_html__( 'Load more', 'adamas' ),
			'noMore'    => esc_html__( 'No more items', 'adamas' ),
		)
	);

	echo '<div class="st-blog-load-more"><a class="load-more-button" href="#" id="st-load-more">' . esc_html__( 'Load more', 'adamas' ) . '</a><div class="st-load-more-animation"><span></span><span></span><span></span></div></div>';
}

// "lazy load" pagination
function st_adamas_lazy_pagination() {
	global $wp_query;

	$max   = $wp_query->max_num_pages;
	$page  = get_query_var( 'paged' );
	$paged = ( $page > 1 ) ? $page : 1;

	wp_enqueue_script( 'st_adamas_blog_lazy_load', get_template_directory_uri() . '/assets/js/blog-lazy-load.js', array( 'jquery' ), false, true );

	wp_localize_script(
		'st_adamas_blog_lazy_load',
		'st_ajax_data',
		array(
			'startPage' => $paged,
			'maxPages'  => $max,
			'nextLink'  => next_posts( $max, false ),
			'container' => '.blog-articles',
		)
	);

	echo '<div class="st-blog-load-more"><div class="st-load-more-animation lazy"><span></span><span></span><span></span></div></div>';
}

// Custom Search Form
function st_adamas_search_form( $form ) {
	ob_start();
	get_template_part( 'templates/searchform' );
	$form = ob_get_clean();

	return $form;
}

add_filter( 'get_search_form', 'st_adamas_search_form' );

// New tagcloud font sizes	
function st_adamas_set_tag_cloud_sizes( $args ) {
	$args['smallest'] = 10;
	$args['largest']  = 10;

	return $args;
}

add_filter( 'widget_tag_cloud_args', 'st_adamas_set_tag_cloud_sizes' );

// Allow SVG through media uploader
function st_adamas_mime_types( $mimes ) {
	$mimes['svg'] = 'image/svg+xml';

	return $mimes;
}

add_filter( 'upload_mimes', 'st_adamas_mime_types' );

// Editor style
function st_adamas_add_editor_styles() {
	global $st_adamas;
	if ( empty( $st_adamas['main_font']['font-family'] ) ) {
		$st_adamas['main_font']['font-family'] = 'Hind';
	}

	add_editor_style( get_template_directory_uri() . '/assets/css/editor-style.css' );
//	add_editor_style( $font_url );
}

add_action( 'admin_init', 'st_adamas_add_editor_styles', 999 );

// Comments template
function st_adamas_comment_template( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	?>
<li id="comment-<?php comment_ID() ?>" <?php comment_class(); ?>>
    <div class="comment-inner">
		<?php if ( get_avatar( $comment, $size = '100' ) ) { ?>
            <div class="comment-author-avatar">
				<?php echo get_avatar( $comment, $size = '100' ); ?>
            </div>
		<?php } ?>
        <div class="comment-info-inner">
            <div class="comment-author"><?php
				if ( $comment->user_id != '0' ) {
					echo get_user_meta( $comment->user_id, 'nickname', true );
				} else {
					echo get_comment_author_link();
				} ?>
            </div>
            <time class="comment-date"
                  datetime="<?php echo get_comment_date( 'Y-m-d', $comment->ID ); ?>"><?php echo get_comment_date( 'F j, Y, g:i a', $comment->ID ); ?></time>
            <div class="comment-reply">
				<?php wp_enqueue_script( 'comment-reply' ); ?>
				<?php if ( is_user_logged_in() ) : ?>
                    <span class="comment-edit">
						<?php edit_comment_link( '<span>' . esc_html__( 'Edit', 'adamas' ) . '</span>', '', '' ); ?>
                    </span>
				<?php endif; ?>
				<?php comment_reply_link( array(
					'depth'      => $depth,
					'max_depth'  => $args['max_depth'],
					'reply_text' => '<span>' . esc_html__( 'Leave reply', 'adamas' ) . '</span>'
				) ); ?>
            </div>
        </div>

        <div class="comment-content">
			<?php if ( $comment->comment_approved == '0' ) : ?>
                <div class="comment-alert">
					<?php esc_html_e( 'Your comment is awaiting moderation.', 'adamas' ); ?>
                </div>
			<?php endif; ?>
			<?php comment_text(); ?>
			<?php echo st_adamas_get_simple_likes_button( get_comment_ID(), 1 ); ?>
        </div>
    </div>
	<?php
}
