<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

global $product;

if ( ! comments_open() ) {
	return;
}

?>
<div id="reviews" class="woocommerce-Reviews">
    <div id="comments">

		<?php if ( have_comments() ) : ?>
            <ol class="commentlist">
				<?php wp_list_comments( apply_filters( 'woocommerce_product_review_list_args', array( 'callback' => 'woocommerce_comments' ) ) ); ?>
            </ol>

			<?php
			if ( get_comment_pages_count() > 1 && get_option( 'page_comments' ) ) :
				echo '<nav class="woocommerce-pagination">';
				paginate_comments_links(
					apply_filters(
						'woocommerce_comment_pagination_args',
						array(
							'prev_text' => '&larr;',
							'next_text' => '&rarr;',
							'type'      => 'list',
						)
					)
				);
				echo '</nav>';
			endif;
			?>
		<?php else : ?>
            <p class="woocommerce-noreviews"><?php esc_html_e( 'There are no reviews yet.', 'adamas' ); ?></p>
		<?php endif; ?>
    </div>

	<?php if ( get_option( 'woocommerce_review_rating_verification_required' ) === 'no' || wc_customer_bought_product( '', get_current_user_id(), $product->get_id() ) ) : ?>
        <div id="review_form_wrapper">
            <div id="review_form">
				<?php
				$commenter = wp_get_current_commenter();

				$comment_form = array(
					'title_reply_before'   => '<h3 id="reply-title" class="comment-reply-title">',
					'title_reply'          => have_comments() ? esc_html__( 'Add a review', 'adamas' ) : sprintf( wp_kses_post( __( 'Be the first to review &ldquo;%s&rdquo;', 'adamas' ) ), get_the_title() ),
					'title_reply_to'       => esc_html__( 'Leave a Reply to %s', 'adamas' ),
					'title_reply_after'    => '</h3>',
					'comment_notes_after'  => '',
					'comment_notes_before' => '',
					'fields'               => array(
						'author'        => '<div class="comment-form-author st-6 col">' . '<label for="author">' . esc_html__( 'Name', 'adamas' ) . ' <span class="required">*</span></label> ' .
						                   '<input id="author" name="author" placeholder="' . esc_attr__( 'Name', 'adamas' ) . '*" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30" required /></div>',
						'email'         => '<div class="comment-form-email st-6 col"><label for="email">' . esc_html__( 'Email', 'adamas' ) . ' <span class="required">*</span></label> ' .
						                   '<input id="email" name="email" placeholder="' . esc_attr__( 'Email', 'adamas' ) . '*" type="email" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30" required /></div>',
						'comment_field' => '<div class="comment-form-comment st-12 col">
<label for="comment">' . esc_html__( 'Your Review', 'adamas' ) . ' <span class="required">*</span></label>
<textarea id="comment" placeholder="' . esc_attr__( 'Review', 'adamas' ) . '*" name="comment" cols="45" rows="8" required></textarea>
</div>',
					),
					'label_submit'         => esc_html__( 'Submit review', 'adamas' ),
					'submit_button'        => '<button name="%1$s" type="submit" id="%2$s" class="%3$s button"><span class="st-submit-review-text">%4$s</span><span class="st-submit-review-icon"><i class="fa fa-angle-right" aria-hidden="true"></i></span></button>',
					'submit_field'         => '<div class="form-submit">%1$s %2$s</div>',
					'logged_in_as'         => ''
				);

				$account_page_url = wc_get_page_permalink( 'myaccount' );
				if ( $account_page_url ) {
					/* translators: %s opening and closing link tags respectively */
					$comment_form['must_log_in'] = '<p class="must-log-in">' . sprintf( esc_html__( 'You must be %1$slogged in%2$s to post a review.', 'adamas' ), '<a href="' . esc_url( $account_page_url ) . '">', '</a>' ) . '</p>';
				}

				if ( wc_review_ratings_enabled() ) {
					$comment_form['comment_field'] = '<div class="comment-form-rating"><label for="rating">' . esc_html__( 'Your rating', 'adamas' ) . '</label><select name="rating" id="rating" required>
						<option value="">' . esc_html__( 'Rate&hellip;', 'adamas' ) . '</option>
						<option value="5">' . esc_html__( 'Perfect', 'adamas' ) . '</option>
						<option value="4">' . esc_html__( 'Good', 'adamas' ) . '</option>
						<option value="3">' . esc_html__( 'Average', 'adamas' ) . '</option>
						<option value="2">' . esc_html__( 'Not that bad', 'adamas' ) . '</option>
						<option value="1">' . esc_html__( 'Very poor', 'adamas' ) . '</option>
					</select></div>';
				}

				$comment_form['comment_field'] .= '<p class="comment-form-comment"><label for="comment">' . esc_html__( 'Your review', 'adamas' ) . '&nbsp;<span class="required">*</span></label><textarea id="comment" name="comment" cols="45" rows="8" required></textarea></p>';

				comment_form( apply_filters( 'woocommerce_product_review_comment_form_args', $comment_form ) );
				?>
            </div>
        </div>
	<?php else : ?>
        <p class="woocommerce-verification-required"><?php esc_html_e( 'Only logged in customers who have purchased this product may leave a review.', 'adamas' ); ?></p>
	<?php endif; ?>

    <div class="clear"></div>
</div>
